Class: EcfDgii::Generated::Ecf31ECF

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf31_ecf.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf31ECF

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf31ECF` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf31ECF`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'encabezado')
    self.encabezado = attributes[:'encabezado']
  else
    self.encabezado = nil
  end

  if attributes.key?(:'detalles_items')
    if (value = attributes[:'detalles_items']).is_a?(Array)
      self.detalles_items = value
    end
  else
    self.detalles_items = nil
  end

  if attributes.key?(:'subtotales')
    if (value = attributes[:'subtotales']).is_a?(Array)
      self.subtotales = value
    end
  end

  if attributes.key?(:'descuentos_o_recargos')
    if (value = attributes[:'descuentos_o_recargos']).is_a?(Array)
      self.descuentos_o_recargos = value
    end
  end

  if attributes.key?(:'paginacion')
    if (value = attributes[:'paginacion']).is_a?(Array)
      self.paginacion = value
    end
  end

  if attributes.key?(:'informacion_referencia')
    self.informacion_referencia = attributes[:'informacion_referencia']
  end
end

Instance Attribute Details

#descuentos_o_recargosObject

Returns the value of attribute descuentos_o_recargos.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 24

def descuentos_o_recargos
  @descuentos_o_recargos
end

#detalles_itemsObject

Returns the value of attribute detalles_items.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 20

def detalles_items
  @detalles_items
end

#encabezadoObject

Returns the value of attribute encabezado.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 18

def encabezado
  @encabezado
end

#informacion_referenciaObject

Returns the value of attribute informacion_referencia.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 28

def informacion_referencia
  @informacion_referencia
end

#paginacionObject

Returns the value of attribute paginacion.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 26

def paginacion
  @paginacion
end

#subtotalesObject

Returns the value of attribute subtotales.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 22

def subtotales
  @subtotales
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 31

def self.attribute_map
  {
    :'encabezado' => :'encabezado',
    :'detalles_items' => :'detallesItems',
    :'subtotales' => :'subtotales',
    :'descuentos_o_recargos' => :'descuentosORecargos',
    :'paginacion' => :'paginacion',
    :'informacion_referencia' => :'informacionReferencia'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
71
72
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 65

def self.openapi_nullable
  Set.new([
    :'subtotales',
    :'descuentos_o_recargos',
    :'paginacion',
    :'informacion_referencia'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 53

def self.openapi_types
  {
    :'encabezado' => :'Ecf31Encabezado',
    :'detalles_items' => :'Array<Ecf31Item>',
    :'subtotales' => :'Array<Ecf31Subtotal>',
    :'descuentos_o_recargos' => :'Array<Ecf31DescuentoORecargo>',
    :'paginacion' => :'Array<Ecf31Pagina>',
    :'informacion_referencia' => :'Ecf31InformacionReferencia'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
183
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      encabezado == o.encabezado &&
      detalles_items == o.detalles_items &&
      subtotales == o.subtotales &&
      descuentos_o_recargos == o.descuentos_o_recargos &&
      paginacion == o.paginacion &&
      informacion_referencia == o.informacion_referencia
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 193

def hash
  [encabezado, detalles_items, subtotales, descuentos_o_recargos, paginacion, informacion_referencia].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @encabezado.nil?
    invalid_properties.push('invalid value for "encabezado", encabezado cannot be nil.')
  end

  if @detalles_items.nil?
    invalid_properties.push('invalid value for "detalles_items", detalles_items cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
# File 'lib/ecf_dgii/generated/models/ecf31_ecf.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @encabezado.nil?
  return false if @detalles_items.nil?
  true
end