Class: EcfDgii::Generated::Ecf31Retencion
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf31Retencion
- Defined in:
- lib/ecf_dgii/generated/models/ecf31_retencion.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#indicador_agente_retenciono_percepcion ⇒ Object
Returns the value of attribute indicador_agente_retenciono_percepcion.
-
#monto_isr_retenido ⇒ Object
Returns the value of attribute monto_isr_retenido.
-
#monto_itbis_retenido ⇒ Object
Returns the value of attribute monto_itbis_retenido.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf31Retencion
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf31Retencion
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf31Retencion` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf31Retencion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'indicador_agente_retenciono_percepcion') self.indicador_agente_retenciono_percepcion = attributes[:'indicador_agente_retenciono_percepcion'] end if attributes.key?(:'monto_itbis_retenido') self.monto_itbis_retenido = attributes[:'monto_itbis_retenido'] end if attributes.key?(:'monto_isr_retenido') self.monto_isr_retenido = attributes[:'monto_isr_retenido'] end end |
Instance Attribute Details
#indicador_agente_retenciono_percepcion ⇒ Object
Returns the value of attribute indicador_agente_retenciono_percepcion.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 18 def indicador_agente_retenciono_percepcion @indicador_agente_retenciono_percepcion end |
#monto_isr_retenido ⇒ Object
Returns the value of attribute monto_isr_retenido.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 22 def monto_isr_retenido @monto_isr_retenido end |
#monto_itbis_retenido ⇒ Object
Returns the value of attribute monto_itbis_retenido.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 20 def monto_itbis_retenido @monto_itbis_retenido end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 47 def self.attribute_map { :'indicador_agente_retenciono_percepcion' => :'indicadorAgenteRetencionoPercepcion', :'monto_itbis_retenido' => :'montoITBISRetenido', :'monto_isr_retenido' => :'montoISRRetenido' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 152 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 79 80 81 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 75 def self.openapi_nullable Set.new([ :'indicador_agente_retenciono_percepcion', :'monto_itbis_retenido', :'monto_isr_retenido' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 66 def self.openapi_types { :'indicador_agente_retenciono_percepcion' => :'IndicadorAgenteRetencionoPercepcionType', :'monto_itbis_retenido' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_isr_retenido' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 129 def ==(o) return true if self.equal?(o) self.class == o.class && indicador_agente_retenciono_percepcion == o.indicador_agente_retenciono_percepcion && monto_itbis_retenido == o.monto_itbis_retenido && monto_isr_retenido == o.monto_isr_retenido end |
#eql?(o) ⇒ Boolean
139 140 141 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 139 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
145 146 147 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 145 def hash [indicador_agente_retenciono_percepcion, monto_itbis_retenido, monto_isr_retenido].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 |
# File 'lib/ecf_dgii/generated/models/ecf31_retencion.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |