Class: EcfDgii::Generated::Ecf31Totales
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf31Totales
- Defined in:
- lib/ecf_dgii/generated/models/ecf31_totales.rb
Instance Attribute Summary collapse
-
#impuestos_adicionales ⇒ Object
Returns the value of attribute impuestos_adicionales.
-
#itbi_s1 ⇒ Object
Returns the value of attribute itbi_s1.
-
#itbi_s2 ⇒ Object
Returns the value of attribute itbi_s2.
-
#itbi_s3 ⇒ Object
Returns the value of attribute itbi_s3.
-
#monto_avance_pago ⇒ Object
Returns the value of attribute monto_avance_pago.
-
#monto_exento ⇒ Object
Returns the value of attribute monto_exento.
-
#monto_gravado_i1 ⇒ Object
Returns the value of attribute monto_gravado_i1.
-
#monto_gravado_i2 ⇒ Object
Returns the value of attribute monto_gravado_i2.
-
#monto_gravado_i3 ⇒ Object
Returns the value of attribute monto_gravado_i3.
-
#monto_gravado_total ⇒ Object
Returns the value of attribute monto_gravado_total.
-
#monto_impuesto_adicional ⇒ Object
Returns the value of attribute monto_impuesto_adicional.
-
#monto_no_facturable ⇒ Object
Returns the value of attribute monto_no_facturable.
-
#monto_periodo ⇒ Object
Returns the value of attribute monto_periodo.
-
#monto_total ⇒ Object
Returns the value of attribute monto_total.
-
#saldo_anterior ⇒ Object
Returns the value of attribute saldo_anterior.
-
#total_isr_percepcion ⇒ Object
Returns the value of attribute total_isr_percepcion.
-
#total_isr_retencion ⇒ Object
Returns the value of attribute total_isr_retencion.
-
#total_itbis ⇒ Object
Returns the value of attribute total_itbis.
-
#total_itbis1 ⇒ Object
Returns the value of attribute total_itbis1.
-
#total_itbis2 ⇒ Object
Returns the value of attribute total_itbis2.
-
#total_itbis3 ⇒ Object
Returns the value of attribute total_itbis3.
-
#total_itbis_percepcion ⇒ Object
Returns the value of attribute total_itbis_percepcion.
-
#total_itbis_retenido ⇒ Object
Returns the value of attribute total_itbis_retenido.
-
#valor_pagar ⇒ Object
Returns the value of attribute valor_pagar.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf31Totales
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf31Totales
Initializes the object
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 167 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf31Totales` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf31Totales`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'monto_gravado_total') self.monto_gravado_total = attributes[:'monto_gravado_total'] end if attributes.key?(:'monto_gravado_i1') self.monto_gravado_i1 = attributes[:'monto_gravado_i1'] end if attributes.key?(:'monto_gravado_i2') self.monto_gravado_i2 = attributes[:'monto_gravado_i2'] end if attributes.key?(:'monto_gravado_i3') self.monto_gravado_i3 = attributes[:'monto_gravado_i3'] end if attributes.key?(:'monto_exento') self.monto_exento = attributes[:'monto_exento'] end if attributes.key?(:'itbi_s1') self.itbi_s1 = attributes[:'itbi_s1'] end if attributes.key?(:'itbi_s2') self.itbi_s2 = attributes[:'itbi_s2'] end if attributes.key?(:'itbi_s3') self.itbi_s3 = attributes[:'itbi_s3'] end if attributes.key?(:'total_itbis') self.total_itbis = attributes[:'total_itbis'] end if attributes.key?(:'total_itbis1') self.total_itbis1 = attributes[:'total_itbis1'] end if attributes.key?(:'total_itbis2') self.total_itbis2 = attributes[:'total_itbis2'] end if attributes.key?(:'total_itbis3') self.total_itbis3 = attributes[:'total_itbis3'] end if attributes.key?(:'monto_impuesto_adicional') self.monto_impuesto_adicional = attributes[:'monto_impuesto_adicional'] end if attributes.key?(:'impuestos_adicionales') if (value = attributes[:'impuestos_adicionales']).is_a?(Array) self.impuestos_adicionales = value end end if attributes.key?(:'monto_total') self.monto_total = attributes[:'monto_total'] else self.monto_total = nil end if attributes.key?(:'monto_no_facturable') self.monto_no_facturable = attributes[:'monto_no_facturable'] end if attributes.key?(:'monto_periodo') self.monto_periodo = attributes[:'monto_periodo'] end if attributes.key?(:'saldo_anterior') self.saldo_anterior = attributes[:'saldo_anterior'] end if attributes.key?(:'monto_avance_pago') self.monto_avance_pago = attributes[:'monto_avance_pago'] end if attributes.key?(:'valor_pagar') self.valor_pagar = attributes[:'valor_pagar'] end if attributes.key?(:'total_itbis_retenido') self.total_itbis_retenido = attributes[:'total_itbis_retenido'] end if attributes.key?(:'total_isr_retencion') self.total_isr_retencion = attributes[:'total_isr_retencion'] end if attributes.key?(:'total_itbis_percepcion') self.total_itbis_percepcion = attributes[:'total_itbis_percepcion'] end if attributes.key?(:'total_isr_percepcion') self.total_isr_percepcion = attributes[:'total_isr_percepcion'] end end |
Instance Attribute Details
#impuestos_adicionales ⇒ Object
Returns the value of attribute impuestos_adicionales.
44 45 46 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 44 def impuestos_adicionales @impuestos_adicionales end |
#itbi_s1 ⇒ Object
Returns the value of attribute itbi_s1.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 28 def itbi_s1 @itbi_s1 end |
#itbi_s2 ⇒ Object
Returns the value of attribute itbi_s2.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 30 def itbi_s2 @itbi_s2 end |
#itbi_s3 ⇒ Object
Returns the value of attribute itbi_s3.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 32 def itbi_s3 @itbi_s3 end |
#monto_avance_pago ⇒ Object
Returns the value of attribute monto_avance_pago.
54 55 56 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 54 def monto_avance_pago @monto_avance_pago end |
#monto_exento ⇒ Object
Returns the value of attribute monto_exento.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 26 def monto_exento @monto_exento end |
#monto_gravado_i1 ⇒ Object
Returns the value of attribute monto_gravado_i1.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 20 def monto_gravado_i1 @monto_gravado_i1 end |
#monto_gravado_i2 ⇒ Object
Returns the value of attribute monto_gravado_i2.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 22 def monto_gravado_i2 @monto_gravado_i2 end |
#monto_gravado_i3 ⇒ Object
Returns the value of attribute monto_gravado_i3.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 24 def monto_gravado_i3 @monto_gravado_i3 end |
#monto_gravado_total ⇒ Object
Returns the value of attribute monto_gravado_total.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 18 def monto_gravado_total @monto_gravado_total end |
#monto_impuesto_adicional ⇒ Object
Returns the value of attribute monto_impuesto_adicional.
42 43 44 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 42 def monto_impuesto_adicional @monto_impuesto_adicional end |
#monto_no_facturable ⇒ Object
Returns the value of attribute monto_no_facturable.
48 49 50 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 48 def monto_no_facturable @monto_no_facturable end |
#monto_periodo ⇒ Object
Returns the value of attribute monto_periodo.
50 51 52 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 50 def monto_periodo @monto_periodo end |
#monto_total ⇒ Object
Returns the value of attribute monto_total.
46 47 48 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 46 def monto_total @monto_total end |
#saldo_anterior ⇒ Object
Returns the value of attribute saldo_anterior.
52 53 54 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 52 def saldo_anterior @saldo_anterior end |
#total_isr_percepcion ⇒ Object
Returns the value of attribute total_isr_percepcion.
64 65 66 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 64 def total_isr_percepcion @total_isr_percepcion end |
#total_isr_retencion ⇒ Object
Returns the value of attribute total_isr_retencion.
60 61 62 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 60 def total_isr_retencion @total_isr_retencion end |
#total_itbis ⇒ Object
Returns the value of attribute total_itbis.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 34 def total_itbis @total_itbis end |
#total_itbis1 ⇒ Object
Returns the value of attribute total_itbis1.
36 37 38 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 36 def total_itbis1 @total_itbis1 end |
#total_itbis2 ⇒ Object
Returns the value of attribute total_itbis2.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 38 def total_itbis2 @total_itbis2 end |
#total_itbis3 ⇒ Object
Returns the value of attribute total_itbis3.
40 41 42 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 40 def total_itbis3 @total_itbis3 end |
#total_itbis_percepcion ⇒ Object
Returns the value of attribute total_itbis_percepcion.
62 63 64 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 62 def total_itbis_percepcion @total_itbis_percepcion end |
#total_itbis_retenido ⇒ Object
Returns the value of attribute total_itbis_retenido.
58 59 60 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 58 def total_itbis_retenido @total_itbis_retenido end |
#valor_pagar ⇒ Object
Returns the value of attribute valor_pagar.
56 57 58 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 56 def valor_pagar @valor_pagar end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
97 98 99 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 97 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
102 103 104 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 102 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 67 def self.attribute_map { :'monto_gravado_total' => :'montoGravadoTotal', :'monto_gravado_i1' => :'montoGravadoI1', :'monto_gravado_i2' => :'montoGravadoI2', :'monto_gravado_i3' => :'montoGravadoI3', :'monto_exento' => :'montoExento', :'itbi_s1' => :'itbiS1', :'itbi_s2' => :'itbiS2', :'itbi_s3' => :'itbiS3', :'total_itbis' => :'totalITBIS', :'total_itbis1' => :'totalITBIS1', :'total_itbis2' => :'totalITBIS2', :'total_itbis3' => :'totalITBIS3', :'monto_impuesto_adicional' => :'montoImpuestoAdicional', :'impuestos_adicionales' => :'impuestosAdicionales', :'monto_total' => :'montoTotal', :'monto_no_facturable' => :'montoNoFacturable', :'monto_periodo' => :'montoPeriodo', :'saldo_anterior' => :'saldoAnterior', :'monto_avance_pago' => :'montoAvancePago', :'valor_pagar' => :'valorPagar', :'total_itbis_retenido' => :'totalITBISRetenido', :'total_isr_retencion' => :'totalISRRetencion', :'total_itbis_percepcion' => :'totalITBISPercepcion', :'total_isr_percepcion' => :'totalISRPercepcion' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 358 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 137 def self.openapi_nullable Set.new([ :'monto_gravado_total', :'monto_gravado_i1', :'monto_gravado_i2', :'monto_gravado_i3', :'monto_exento', :'itbi_s1', :'itbi_s2', :'itbi_s3', :'total_itbis', :'total_itbis1', :'total_itbis2', :'total_itbis3', :'monto_impuesto_adicional', :'impuestos_adicionales', :'monto_no_facturable', :'monto_periodo', :'saldo_anterior', :'monto_avance_pago', :'valor_pagar', :'total_itbis_retenido', :'total_isr_retencion', :'total_itbis_percepcion', :'total_isr_percepcion' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 107 def self.openapi_types { :'monto_gravado_total' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_gravado_i1' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_gravado_i2' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_gravado_i3' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_exento' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'itbi_s1' => :'AcecfSummaryDtoReceptorHttpStatus', :'itbi_s2' => :'AcecfSummaryDtoReceptorHttpStatus', :'itbi_s3' => :'AcecfSummaryDtoReceptorHttpStatus', :'total_itbis' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis1' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis2' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis3' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_impuesto_adicional' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico', :'impuestos_adicionales' => :'Array<Ecf31ImpuestoAdicional2>', :'monto_total' => :'Ecf31FormaDePagoMontoPago', :'monto_no_facturable' => :'Ecf31TotalesMontoNoFacturable', :'monto_periodo' => :'Ecf31TotalesMontoNoFacturable', :'saldo_anterior' => :'Ecf31TotalesMontoNoFacturable', :'monto_avance_pago' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'valor_pagar' => :'Ecf31TotalesMontoNoFacturable', :'total_itbis_retenido' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_isr_retencion' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis_percepcion' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_isr_percepcion' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 314 def ==(o) return true if self.equal?(o) self.class == o.class && monto_gravado_total == o.monto_gravado_total && monto_gravado_i1 == o.monto_gravado_i1 && monto_gravado_i2 == o.monto_gravado_i2 && monto_gravado_i3 == o.monto_gravado_i3 && monto_exento == o.monto_exento && itbi_s1 == o.itbi_s1 && itbi_s2 == o.itbi_s2 && itbi_s3 == o.itbi_s3 && total_itbis == o.total_itbis && total_itbis1 == o.total_itbis1 && total_itbis2 == o.total_itbis2 && total_itbis3 == o.total_itbis3 && monto_impuesto_adicional == o.monto_impuesto_adicional && impuestos_adicionales == o.impuestos_adicionales && monto_total == o.monto_total && monto_no_facturable == o.monto_no_facturable && monto_periodo == o.monto_periodo && saldo_anterior == o.saldo_anterior && monto_avance_pago == o.monto_avance_pago && valor_pagar == o.valor_pagar && total_itbis_retenido == o.total_itbis_retenido && total_isr_retencion == o.total_isr_retencion && total_itbis_percepcion == o.total_itbis_percepcion && total_isr_percepcion == o.total_isr_percepcion end |
#eql?(o) ⇒ Boolean
345 346 347 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 345 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
351 352 353 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 351 def hash [monto_gravado_total, monto_gravado_i1, monto_gravado_i2, monto_gravado_i3, monto_exento, itbi_s1, itbi_s2, itbi_s3, total_itbis, total_itbis1, total_itbis2, total_itbis3, monto_impuesto_adicional, impuestos_adicionales, monto_total, monto_no_facturable, monto_periodo, saldo_anterior, monto_avance_pago, valor_pagar, total_itbis_retenido, total_isr_retencion, total_itbis_percepcion, total_isr_percepcion].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
284 285 286 287 288 289 290 291 292 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 284 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @monto_total.nil? invalid_properties.push('invalid value for "monto_total", monto_total cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 380 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
296 297 298 299 300 |
# File 'lib/ecf_dgii/generated/models/ecf31_totales.rb', line 296 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @monto_total.nil? true end |