Class: EcfDgii::Generated::Ecf32Comprador

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf32_comprador.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf32Comprador

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 155

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf32Comprador` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf32Comprador`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rnc_comprador')
    self.rnc_comprador = attributes[:'rnc_comprador']
  end

  if attributes.key?(:'identificador_extranjero')
    self.identificador_extranjero = attributes[:'identificador_extranjero']
  end

  if attributes.key?(:'razon_social_comprador')
    self.razon_social_comprador = attributes[:'razon_social_comprador']
  end

  if attributes.key?(:'contacto_comprador')
    self.contacto_comprador = attributes[:'contacto_comprador']
  end

  if attributes.key?(:'correo_comprador')
    self.correo_comprador = attributes[:'correo_comprador']
  end

  if attributes.key?(:'direccion_comprador')
    self.direccion_comprador = attributes[:'direccion_comprador']
  end

  if attributes.key?(:'municipio_comprador')
    self.municipio_comprador = attributes[:'municipio_comprador']
  end

  if attributes.key?(:'provincia_comprador')
    self.provincia_comprador = attributes[:'provincia_comprador']
  end

  if attributes.key?(:'fecha_entrega')
    self.fecha_entrega = attributes[:'fecha_entrega']
  end

  if attributes.key?(:'contacto_entrega')
    self.contacto_entrega = attributes[:'contacto_entrega']
  end

  if attributes.key?(:'direccion_entrega')
    self.direccion_entrega = attributes[:'direccion_entrega']
  end

  if attributes.key?(:'telefono_adicional')
    self.telefono_adicional = attributes[:'telefono_adicional']
  end

  if attributes.key?(:'fecha_orden_compra')
    self.fecha_orden_compra = attributes[:'fecha_orden_compra']
  end

  if attributes.key?(:'numero_orden_compra')
    self.numero_orden_compra = attributes[:'numero_orden_compra']
  end

  if attributes.key?(:'codigo_interno_comprador')
    self.codigo_interno_comprador = attributes[:'codigo_interno_comprador']
  end

  if attributes.key?(:'responsable_pago')
    self.responsable_pago = attributes[:'responsable_pago']
  end

  if attributes.key?(:'informacion_adicional_comprador')
    self.informacion_adicional_comprador = attributes[:'informacion_adicional_comprador']
  end
end

Instance Attribute Details

#codigo_interno_compradorObject

Returns the value of attribute codigo_interno_comprador.



46
47
48
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 46

def codigo_interno_comprador
  @codigo_interno_comprador
end

#contacto_compradorObject

Returns the value of attribute contacto_comprador.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 24

def contacto_comprador
  @contacto_comprador
end

#contacto_entregaObject

Returns the value of attribute contacto_entrega.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 36

def contacto_entrega
  @contacto_entrega
end

#correo_compradorObject

Returns the value of attribute correo_comprador.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 26

def correo_comprador
  @correo_comprador
end

#direccion_compradorObject

Returns the value of attribute direccion_comprador.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 28

def direccion_comprador
  @direccion_comprador
end

#direccion_entregaObject

Returns the value of attribute direccion_entrega.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 38

def direccion_entrega
  @direccion_entrega
end

#fecha_entregaObject

Returns the value of attribute fecha_entrega.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 34

def fecha_entrega
  @fecha_entrega
end

#fecha_orden_compraObject

Returns the value of attribute fecha_orden_compra.



42
43
44
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 42

def fecha_orden_compra
  @fecha_orden_compra
end

#identificador_extranjeroObject

Returns the value of attribute identificador_extranjero.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 20

def identificador_extranjero
  @identificador_extranjero
end

#informacion_adicional_compradorObject

Returns the value of attribute informacion_adicional_comprador.



50
51
52
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 50

def informacion_adicional_comprador
  @informacion_adicional_comprador
end

#municipio_compradorObject

Returns the value of attribute municipio_comprador.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 30

def municipio_comprador
  @municipio_comprador
end

#numero_orden_compraObject

Returns the value of attribute numero_orden_compra.



44
45
46
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 44

def numero_orden_compra
  @numero_orden_compra
end

#provincia_compradorObject

Returns the value of attribute provincia_comprador.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 32

def provincia_comprador
  @provincia_comprador
end

#razon_social_compradorObject

Returns the value of attribute razon_social_comprador.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 22

def razon_social_comprador
  @razon_social_comprador
end

#responsable_pagoObject

Returns the value of attribute responsable_pago.



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 48

def responsable_pago
  @responsable_pago
end

#rnc_compradorObject

Returns the value of attribute rnc_comprador.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 18

def rnc_comprador
  @rnc_comprador
end

#telefono_adicionalObject

Returns the value of attribute telefono_adicional.



40
41
42
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 40

def telefono_adicional
  @telefono_adicional
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



98
99
100
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 103

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 75

def self.attribute_map
  {
    :'rnc_comprador' => :'rncComprador',
    :'identificador_extranjero' => :'identificadorExtranjero',
    :'razon_social_comprador' => :'razonSocialComprador',
    :'contacto_comprador' => :'contactoComprador',
    :'correo_comprador' => :'correoComprador',
    :'direccion_comprador' => :'direccionComprador',
    :'municipio_comprador' => :'municipioComprador',
    :'provincia_comprador' => :'provinciaComprador',
    :'fecha_entrega' => :'fechaEntrega',
    :'contacto_entrega' => :'contactoEntrega',
    :'direccion_entrega' => :'direccionEntrega',
    :'telefono_adicional' => :'telefonoAdicional',
    :'fecha_orden_compra' => :'fechaOrdenCompra',
    :'numero_orden_compra' => :'numeroOrdenCompra',
    :'codigo_interno_comprador' => :'codigoInternoComprador',
    :'responsable_pago' => :'responsablePago',
    :'informacion_adicional_comprador' => :'informacionAdicionalComprador'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 292

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 131

def self.openapi_nullable
  Set.new([
    :'rnc_comprador',
    :'identificador_extranjero',
    :'razon_social_comprador',
    :'contacto_comprador',
    :'correo_comprador',
    :'direccion_comprador',
    :'municipio_comprador',
    :'provincia_comprador',
    :'fecha_entrega',
    :'contacto_entrega',
    :'direccion_entrega',
    :'telefono_adicional',
    :'fecha_orden_compra',
    :'numero_orden_compra',
    :'codigo_interno_comprador',
    :'responsable_pago',
    :'informacion_adicional_comprador'
  ])
end

.openapi_typesObject

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 108

def self.openapi_types
  {
    :'rnc_comprador' => :'String',
    :'identificador_extranjero' => :'String',
    :'razon_social_comprador' => :'String',
    :'contacto_comprador' => :'String',
    :'correo_comprador' => :'String',
    :'direccion_comprador' => :'String',
    :'municipio_comprador' => :'ProvinciaMunicipioType',
    :'provincia_comprador' => :'ProvinciaMunicipioType',
    :'fecha_entrega' => :'Time',
    :'contacto_entrega' => :'String',
    :'direccion_entrega' => :'String',
    :'telefono_adicional' => :'String',
    :'fecha_orden_compra' => :'Time',
    :'numero_orden_compra' => :'String',
    :'codigo_interno_comprador' => :'String',
    :'responsable_pago' => :'String',
    :'informacion_adicional_comprador' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 255

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rnc_comprador == o.rnc_comprador &&
      identificador_extranjero == o.identificador_extranjero &&
      razon_social_comprador == o.razon_social_comprador &&
      contacto_comprador == o.contacto_comprador &&
      correo_comprador == o.correo_comprador &&
      direccion_comprador == o.direccion_comprador &&
      municipio_comprador == o.municipio_comprador &&
      provincia_comprador == o.provincia_comprador &&
      fecha_entrega == o.fecha_entrega &&
      contacto_entrega == o.contacto_entrega &&
      direccion_entrega == o.direccion_entrega &&
      telefono_adicional == o.telefono_adicional &&
      fecha_orden_compra == o.fecha_orden_compra &&
      numero_orden_compra == o.numero_orden_compra &&
      codigo_interno_comprador == o.codigo_interno_comprador &&
      responsable_pago == o.responsable_pago &&
      informacion_adicional_comprador == o.informacion_adicional_comprador
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


279
280
281
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 279

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



285
286
287
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 285

def hash
  [rnc_comprador, identificador_extranjero, razon_social_comprador, contacto_comprador, correo_comprador, direccion_comprador, municipio_comprador, provincia_comprador, fecha_entrega, contacto_entrega, direccion_entrega, telefono_adicional, fecha_orden_compra, numero_orden_compra, codigo_interno_comprador, responsable_pago, informacion_adicional_comprador].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



240
241
242
243
244
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 240

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



248
249
250
251
# File 'lib/ecf_dgii/generated/models/ecf32_comprador.rb', line 248

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end