Class: EcfDgii::Generated::Ecf32Encabezado

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf32_encabezado.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf32Encabezado

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf32Encabezado` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf32Encabezado`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'id_doc')
    self.id_doc = attributes[:'id_doc']
  else
    self.id_doc = nil
  end

  if attributes.key?(:'emisor')
    self.emisor = attributes[:'emisor']
  else
    self.emisor = nil
  end

  if attributes.key?(:'comprador')
    self.comprador = attributes[:'comprador']
  else
    self.comprador = nil
  end

  if attributes.key?(:'informaciones_adicionales')
    self.informaciones_adicionales = attributes[:'informaciones_adicionales']
  end

  if attributes.key?(:'transporte')
    self.transporte = attributes[:'transporte']
  end

  if attributes.key?(:'totales')
    self.totales = attributes[:'totales']
  else
    self.totales = nil
  end

  if attributes.key?(:'otra_moneda')
    self.otra_moneda = attributes[:'otra_moneda']
  end
end

Instance Attribute Details

#compradorObject

Returns the value of attribute comprador.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 24

def comprador
  @comprador
end

#emisorObject

Returns the value of attribute emisor.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 22

def emisor
  @emisor
end

#id_docObject

Returns the value of attribute id_doc.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 20

def id_doc
  @id_doc
end

#informaciones_adicionalesObject

Returns the value of attribute informaciones_adicionales.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 26

def informaciones_adicionales
  @informaciones_adicionales
end

#otra_monedaObject

Returns the value of attribute otra_moneda.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 32

def otra_moneda
  @otra_moneda
end

#totalesObject

Returns the value of attribute totales.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 30

def totales
  @totales
end

#transporteObject

Returns the value of attribute transporte.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 28

def transporte
  @transporte
end

#versionObject

Returns the value of attribute version.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 18

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 57

def self.attribute_map
  {
    :'version' => :'version',
    :'id_doc' => :'idDoc',
    :'emisor' => :'emisor',
    :'comprador' => :'comprador',
    :'informaciones_adicionales' => :'informacionesAdicionales',
    :'transporte' => :'transporte',
    :'totales' => :'totales',
    :'otra_moneda' => :'otraMoneda'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
99
100
101
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 95

def self.openapi_nullable
  Set.new([
    :'informaciones_adicionales',
    :'transporte',
    :'otra_moneda'
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 81

def self.openapi_types
  {
    :'version' => :'Ecf32VersionType',
    :'id_doc' => :'Ecf32IdDoc',
    :'emisor' => :'Ecf32Emisor',
    :'comprador' => :'Ecf32Comprador',
    :'informaciones_adicionales' => :'Ecf32InformacionesAdicionales',
    :'transporte' => :'Ecf32Transporte',
    :'totales' => :'Ecf32Totales',
    :'otra_moneda' => :'Ecf32OtraMoneda'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version == o.version &&
      id_doc == o.id_doc &&
      emisor == o.emisor &&
      comprador == o.comprador &&
      informaciones_adicionales == o.informaciones_adicionales &&
      transporte == o.transporte &&
      totales == o.totales &&
      otra_moneda == o.otra_moneda
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 275

def hash
  [version, id_doc, emisor, comprador, informaciones_adicionales, transporte, totales, otra_moneda].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @id_doc.nil?
    invalid_properties.push('invalid value for "id_doc", id_doc cannot be nil.')
  end

  if @emisor.nil?
    invalid_properties.push('invalid value for "emisor", emisor cannot be nil.')
  end

  if @comprador.nil?
    invalid_properties.push('invalid value for "comprador", comprador cannot be nil.')
  end

  if @totales.nil?
    invalid_properties.push('invalid value for "totales", totales cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
# File 'lib/ecf_dgii/generated/models/ecf32_encabezado.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @version.nil?
  return false if @id_doc.nil?
  return false if @emisor.nil?
  return false if @comprador.nil?
  return false if @totales.nil?
  true
end