Class: EcfDgii::Generated::Ecf32Subtotal
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf32Subtotal
- Defined in:
- lib/ecf_dgii/generated/models/ecf32_subtotal.rb
Instance Attribute Summary collapse
-
#descripcion_subtotal ⇒ Object
Returns the value of attribute descripcion_subtotal.
-
#lineas ⇒ Object
Returns the value of attribute lineas.
-
#monto_sub_total ⇒ Object
Returns the value of attribute monto_sub_total.
-
#numero_sub_total ⇒ Object
Returns the value of attribute numero_sub_total.
-
#orden ⇒ Object
Returns the value of attribute orden.
-
#sub_tota_itbis ⇒ Object
Returns the value of attribute sub_tota_itbis.
-
#sub_tota_itbis1 ⇒ Object
Returns the value of attribute sub_tota_itbis1.
-
#sub_tota_itbis2 ⇒ Object
Returns the value of attribute sub_tota_itbis2.
-
#sub_tota_itbis3 ⇒ Object
Returns the value of attribute sub_tota_itbis3.
-
#sub_total_exento ⇒ Object
Returns the value of attribute sub_total_exento.
-
#sub_total_impuesto_adicional ⇒ Object
Returns the value of attribute sub_total_impuesto_adicional.
-
#sub_total_monto_gravado_i1 ⇒ Object
Returns the value of attribute sub_total_monto_gravado_i1.
-
#sub_total_monto_gravado_i2 ⇒ Object
Returns the value of attribute sub_total_monto_gravado_i2.
-
#sub_total_monto_gravado_i3 ⇒ Object
Returns the value of attribute sub_total_monto_gravado_i3.
-
#sub_total_monto_gravado_total ⇒ Object
Returns the value of attribute sub_total_monto_gravado_total.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf32Subtotal
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf32Subtotal
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf32Subtotal` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf32Subtotal`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'numero_sub_total') self.numero_sub_total = attributes[:'numero_sub_total'] end if attributes.key?(:'descripcion_subtotal') self.descripcion_subtotal = attributes[:'descripcion_subtotal'] end if attributes.key?(:'orden') self.orden = attributes[:'orden'] end if attributes.key?(:'sub_total_monto_gravado_total') self.sub_total_monto_gravado_total = attributes[:'sub_total_monto_gravado_total'] end if attributes.key?(:'sub_total_monto_gravado_i1') self.sub_total_monto_gravado_i1 = attributes[:'sub_total_monto_gravado_i1'] end if attributes.key?(:'sub_total_monto_gravado_i2') self.sub_total_monto_gravado_i2 = attributes[:'sub_total_monto_gravado_i2'] end if attributes.key?(:'sub_total_monto_gravado_i3') self.sub_total_monto_gravado_i3 = attributes[:'sub_total_monto_gravado_i3'] end if attributes.key?(:'sub_tota_itbis') self.sub_tota_itbis = attributes[:'sub_tota_itbis'] end if attributes.key?(:'sub_tota_itbis1') self.sub_tota_itbis1 = attributes[:'sub_tota_itbis1'] end if attributes.key?(:'sub_tota_itbis2') self.sub_tota_itbis2 = attributes[:'sub_tota_itbis2'] end if attributes.key?(:'sub_tota_itbis3') self.sub_tota_itbis3 = attributes[:'sub_tota_itbis3'] end if attributes.key?(:'sub_total_impuesto_adicional') self.sub_total_impuesto_adicional = attributes[:'sub_total_impuesto_adicional'] end if attributes.key?(:'sub_total_exento') self.sub_total_exento = attributes[:'sub_total_exento'] end if attributes.key?(:'monto_sub_total') self.monto_sub_total = attributes[:'monto_sub_total'] end if attributes.key?(:'lineas') self.lineas = attributes[:'lineas'] end end |
Instance Attribute Details
#descripcion_subtotal ⇒ Object
Returns the value of attribute descripcion_subtotal.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 20 def descripcion_subtotal @descripcion_subtotal end |
#lineas ⇒ Object
Returns the value of attribute lineas.
46 47 48 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 46 def lineas @lineas end |
#monto_sub_total ⇒ Object
Returns the value of attribute monto_sub_total.
44 45 46 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 44 def monto_sub_total @monto_sub_total end |
#numero_sub_total ⇒ Object
Returns the value of attribute numero_sub_total.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 18 def numero_sub_total @numero_sub_total end |
#orden ⇒ Object
Returns the value of attribute orden.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 22 def orden @orden end |
#sub_tota_itbis ⇒ Object
Returns the value of attribute sub_tota_itbis.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 32 def sub_tota_itbis @sub_tota_itbis end |
#sub_tota_itbis1 ⇒ Object
Returns the value of attribute sub_tota_itbis1.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 34 def sub_tota_itbis1 @sub_tota_itbis1 end |
#sub_tota_itbis2 ⇒ Object
Returns the value of attribute sub_tota_itbis2.
36 37 38 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 36 def sub_tota_itbis2 @sub_tota_itbis2 end |
#sub_tota_itbis3 ⇒ Object
Returns the value of attribute sub_tota_itbis3.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 38 def sub_tota_itbis3 @sub_tota_itbis3 end |
#sub_total_exento ⇒ Object
Returns the value of attribute sub_total_exento.
42 43 44 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 42 def sub_total_exento @sub_total_exento end |
#sub_total_impuesto_adicional ⇒ Object
Returns the value of attribute sub_total_impuesto_adicional.
40 41 42 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 40 def sub_total_impuesto_adicional @sub_total_impuesto_adicional end |
#sub_total_monto_gravado_i1 ⇒ Object
Returns the value of attribute sub_total_monto_gravado_i1.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 26 def sub_total_monto_gravado_i1 @sub_total_monto_gravado_i1 end |
#sub_total_monto_gravado_i2 ⇒ Object
Returns the value of attribute sub_total_monto_gravado_i2.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 28 def sub_total_monto_gravado_i2 @sub_total_monto_gravado_i2 end |
#sub_total_monto_gravado_i3 ⇒ Object
Returns the value of attribute sub_total_monto_gravado_i3.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 30 def sub_total_monto_gravado_i3 @sub_total_monto_gravado_i3 end |
#sub_total_monto_gravado_total ⇒ Object
Returns the value of attribute sub_total_monto_gravado_total.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 24 def sub_total_monto_gravado_total @sub_total_monto_gravado_total end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 49 def self.attribute_map { :'numero_sub_total' => :'numeroSubTotal', :'descripcion_subtotal' => :'descripcionSubtotal', :'orden' => :'orden', :'sub_total_monto_gravado_total' => :'subTotalMontoGravadoTotal', :'sub_total_monto_gravado_i1' => :'subTotalMontoGravadoI1', :'sub_total_monto_gravado_i2' => :'subTotalMontoGravadoI2', :'sub_total_monto_gravado_i3' => :'subTotalMontoGravadoI3', :'sub_tota_itbis' => :'subTotaITBIS', :'sub_tota_itbis1' => :'subTotaITBIS1', :'sub_tota_itbis2' => :'subTotaITBIS2', :'sub_tota_itbis3' => :'subTotaITBIS3', :'sub_total_impuesto_adicional' => :'subTotalImpuestoAdicional', :'sub_total_exento' => :'subTotalExento', :'monto_sub_total' => :'montoSubTotal', :'lineas' => :'lineas' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 250 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 101 def self.openapi_nullable Set.new([ :'numero_sub_total', :'descripcion_subtotal', :'orden', :'sub_total_monto_gravado_total', :'sub_total_monto_gravado_i1', :'sub_total_monto_gravado_i2', :'sub_total_monto_gravado_i3', :'sub_tota_itbis', :'sub_tota_itbis1', :'sub_tota_itbis2', :'sub_tota_itbis3', :'sub_total_impuesto_adicional', :'sub_total_exento', :'monto_sub_total', :'lineas' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 80 def self.openapi_types { :'numero_sub_total' => :'AcecfSummaryDtoReceptorHttpStatus', :'descripcion_subtotal' => :'String', :'orden' => :'AcecfSummaryDtoReceptorHttpStatus', :'sub_total_monto_gravado_total' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_total_monto_gravado_i1' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_total_monto_gravado_i2' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_total_monto_gravado_i3' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_tota_itbis' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_tota_itbis1' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_tota_itbis2' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_tota_itbis3' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_total_impuesto_adicional' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'sub_total_exento' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_sub_total' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'lineas' => :'AcecfSummaryDtoReceptorHttpStatus' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && numero_sub_total == o.numero_sub_total && descripcion_subtotal == o.descripcion_subtotal && orden == o.orden && sub_total_monto_gravado_total == o.sub_total_monto_gravado_total && sub_total_monto_gravado_i1 == o.sub_total_monto_gravado_i1 && sub_total_monto_gravado_i2 == o.sub_total_monto_gravado_i2 && sub_total_monto_gravado_i3 == o.sub_total_monto_gravado_i3 && sub_tota_itbis == o.sub_tota_itbis && sub_tota_itbis1 == o.sub_tota_itbis1 && sub_tota_itbis2 == o.sub_tota_itbis2 && sub_tota_itbis3 == o.sub_tota_itbis3 && sub_total_impuesto_adicional == o.sub_total_impuesto_adicional && sub_total_exento == o.sub_total_exento && monto_sub_total == o.monto_sub_total && lineas == o.lineas end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 243 def hash [numero_sub_total, descripcion_subtotal, orden, sub_total_monto_gravado_total, sub_total_monto_gravado_i1, sub_total_monto_gravado_i2, sub_total_monto_gravado_i3, sub_tota_itbis, sub_tota_itbis1, sub_tota_itbis2, sub_tota_itbis3, sub_total_impuesto_adicional, sub_total_exento, monto_sub_total, lineas].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 204 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 200 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 |
# File 'lib/ecf_dgii/generated/models/ecf32_subtotal.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |