Class: EcfDgii::Generated::Ecf34Emisor
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf34Emisor
- Defined in:
- lib/ecf_dgii/generated/models/ecf34_emisor.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#actividad_economica ⇒ Object
Returns the value of attribute actividad_economica.
-
#codigo_vendedor ⇒ Object
Returns the value of attribute codigo_vendedor.
-
#correo_emisor ⇒ Object
Returns the value of attribute correo_emisor.
-
#direccion_emisor ⇒ Object
Returns the value of attribute direccion_emisor.
-
#fecha_emision ⇒ Object
Returns the value of attribute fecha_emision.
-
#informacion_adicional_emisor ⇒ Object
Returns the value of attribute informacion_adicional_emisor.
-
#municipio ⇒ Object
Returns the value of attribute municipio.
-
#nombre_comercial ⇒ Object
Returns the value of attribute nombre_comercial.
-
#numero_factura_interna ⇒ Object
Returns the value of attribute numero_factura_interna.
-
#numero_pedido_interno ⇒ Object
Returns the value of attribute numero_pedido_interno.
-
#provincia ⇒ Object
Returns the value of attribute provincia.
-
#razon_social_emisor ⇒ Object
Returns the value of attribute razon_social_emisor.
-
#rnc_emisor ⇒ Object
Returns the value of attribute rnc_emisor.
-
#ruta_venta ⇒ Object
Returns the value of attribute ruta_venta.
-
#sucursal ⇒ Object
Returns the value of attribute sucursal.
-
#tabla_telefono_emisor ⇒ Object
Returns the value of attribute tabla_telefono_emisor.
-
#web_site ⇒ Object
Returns the value of attribute web_site.
-
#zona_venta ⇒ Object
Returns the value of attribute zona_venta.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf34Emisor
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf34Emisor
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 156 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf34Emisor` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf34Emisor`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'rnc_emisor') self.rnc_emisor = attributes[:'rnc_emisor'] else self.rnc_emisor = nil end if attributes.key?(:'razon_social_emisor') self. = attributes[:'razon_social_emisor'] else self. = nil end if attributes.key?(:'nombre_comercial') self.nombre_comercial = attributes[:'nombre_comercial'] end if attributes.key?(:'sucursal') self.sucursal = attributes[:'sucursal'] end if attributes.key?(:'direccion_emisor') self.direccion_emisor = attributes[:'direccion_emisor'] else self.direccion_emisor = nil end if attributes.key?(:'municipio') self.municipio = attributes[:'municipio'] end if attributes.key?(:'provincia') self.provincia = attributes[:'provincia'] end if attributes.key?(:'tabla_telefono_emisor') if (value = attributes[:'tabla_telefono_emisor']).is_a?(Array) self.tabla_telefono_emisor = value end end if attributes.key?(:'correo_emisor') self.correo_emisor = attributes[:'correo_emisor'] end if attributes.key?(:'web_site') self.web_site = attributes[:'web_site'] end if attributes.key?(:'actividad_economica') self.actividad_economica = attributes[:'actividad_economica'] end if attributes.key?(:'codigo_vendedor') self.codigo_vendedor = attributes[:'codigo_vendedor'] end if attributes.key?(:'numero_factura_interna') self.numero_factura_interna = attributes[:'numero_factura_interna'] end if attributes.key?(:'numero_pedido_interno') self.numero_pedido_interno = attributes[:'numero_pedido_interno'] end if attributes.key?(:'zona_venta') self.zona_venta = attributes[:'zona_venta'] end if attributes.key?(:'ruta_venta') self.ruta_venta = attributes[:'ruta_venta'] end if attributes.key?(:'informacion_adicional_emisor') self.informacion_adicional_emisor = attributes[:'informacion_adicional_emisor'] end if attributes.key?(:'fecha_emision') self.fecha_emision = attributes[:'fecha_emision'] end end |
Instance Attribute Details
#actividad_economica ⇒ Object
Returns the value of attribute actividad_economica.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 38 def actividad_economica @actividad_economica end |
#codigo_vendedor ⇒ Object
Returns the value of attribute codigo_vendedor.
40 41 42 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 40 def codigo_vendedor @codigo_vendedor end |
#correo_emisor ⇒ Object
Returns the value of attribute correo_emisor.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 34 def correo_emisor @correo_emisor end |
#direccion_emisor ⇒ Object
Returns the value of attribute direccion_emisor.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 26 def direccion_emisor @direccion_emisor end |
#fecha_emision ⇒ Object
Returns the value of attribute fecha_emision.
52 53 54 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 52 def fecha_emision @fecha_emision end |
#informacion_adicional_emisor ⇒ Object
Returns the value of attribute informacion_adicional_emisor.
50 51 52 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 50 def informacion_adicional_emisor @informacion_adicional_emisor end |
#municipio ⇒ Object
Returns the value of attribute municipio.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 28 def municipio @municipio end |
#nombre_comercial ⇒ Object
Returns the value of attribute nombre_comercial.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 22 def nombre_comercial @nombre_comercial end |
#numero_factura_interna ⇒ Object
Returns the value of attribute numero_factura_interna.
42 43 44 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 42 def numero_factura_interna @numero_factura_interna end |
#numero_pedido_interno ⇒ Object
Returns the value of attribute numero_pedido_interno.
44 45 46 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 44 def numero_pedido_interno @numero_pedido_interno end |
#provincia ⇒ Object
Returns the value of attribute provincia.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 30 def provincia @provincia end |
#razon_social_emisor ⇒ Object
Returns the value of attribute razon_social_emisor.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 20 def @razon_social_emisor end |
#rnc_emisor ⇒ Object
Returns the value of attribute rnc_emisor.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 18 def rnc_emisor @rnc_emisor end |
#ruta_venta ⇒ Object
Returns the value of attribute ruta_venta.
48 49 50 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 48 def ruta_venta @ruta_venta end |
#sucursal ⇒ Object
Returns the value of attribute sucursal.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 24 def sucursal @sucursal end |
#tabla_telefono_emisor ⇒ Object
Returns the value of attribute tabla_telefono_emisor.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 32 def tabla_telefono_emisor @tabla_telefono_emisor end |
#web_site ⇒ Object
Returns the value of attribute web_site.
36 37 38 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 36 def web_site @web_site end |
#zona_venta ⇒ Object
Returns the value of attribute zona_venta.
46 47 48 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 46 def zona_venta @zona_venta end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
101 102 103 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 101 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
106 107 108 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 106 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 77 def self.attribute_map { :'rnc_emisor' => :'rncEmisor', :'razon_social_emisor' => :'razonSocialEmisor', :'nombre_comercial' => :'nombreComercial', :'sucursal' => :'sucursal', :'direccion_emisor' => :'direccionEmisor', :'municipio' => :'municipio', :'provincia' => :'provincia', :'tabla_telefono_emisor' => :'tablaTelefonoEmisor', :'correo_emisor' => :'correoEmisor', :'web_site' => :'webSite', :'actividad_economica' => :'actividadEconomica', :'codigo_vendedor' => :'codigoVendedor', :'numero_factura_interna' => :'numeroFacturaInterna', :'numero_pedido_interno' => :'numeroPedidoInterno', :'zona_venta' => :'zonaVenta', :'ruta_venta' => :'rutaVenta', :'informacion_adicional_emisor' => :'informacionAdicionalEmisor', :'fecha_emision' => :'fechaEmision' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 368 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 135 def self.openapi_nullable Set.new([ :'nombre_comercial', :'sucursal', :'municipio', :'provincia', :'tabla_telefono_emisor', :'correo_emisor', :'web_site', :'actividad_economica', :'codigo_vendedor', :'numero_factura_interna', :'numero_pedido_interno', :'zona_venta', :'ruta_venta', :'informacion_adicional_emisor', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 111 def self.openapi_types { :'rnc_emisor' => :'String', :'razon_social_emisor' => :'String', :'nombre_comercial' => :'String', :'sucursal' => :'String', :'direccion_emisor' => :'String', :'municipio' => :'ProvinciaMunicipioType', :'provincia' => :'ProvinciaMunicipioType', :'tabla_telefono_emisor' => :'Array<String>', :'correo_emisor' => :'String', :'web_site' => :'String', :'actividad_economica' => :'String', :'codigo_vendedor' => :'String', :'numero_factura_interna' => :'String', :'numero_pedido_interno' => :'String', :'zona_venta' => :'String', :'ruta_venta' => :'String', :'informacion_adicional_emisor' => :'String', :'fecha_emision' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 330 def ==(o) return true if self.equal?(o) self.class == o.class && rnc_emisor == o.rnc_emisor && == o. && nombre_comercial == o.nombre_comercial && sucursal == o.sucursal && direccion_emisor == o.direccion_emisor && municipio == o.municipio && provincia == o.provincia && tabla_telefono_emisor == o.tabla_telefono_emisor && correo_emisor == o.correo_emisor && web_site == o.web_site && actividad_economica == o.actividad_economica && codigo_vendedor == o.codigo_vendedor && numero_factura_interna == o.numero_factura_interna && numero_pedido_interno == o.numero_pedido_interno && zona_venta == o.zona_venta && ruta_venta == o.ruta_venta && informacion_adicional_emisor == o.informacion_adicional_emisor && fecha_emision == o.fecha_emision end |
#eql?(o) ⇒ Boolean
355 356 357 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 355 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
361 362 363 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 361 def hash [rnc_emisor, , nombre_comercial, sucursal, direccion_emisor, municipio, provincia, tabla_telefono_emisor, correo_emisor, web_site, actividad_economica, codigo_vendedor, numero_factura_interna, numero_pedido_interno, zona_venta, ruta_venta, informacion_adicional_emisor, fecha_emision].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 253 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @rnc_emisor.nil? invalid_properties.push('invalid value for "rnc_emisor", rnc_emisor cannot be nil.') end if @razon_social_emisor.nil? invalid_properties.push('invalid value for "razon_social_emisor", razon_social_emisor cannot be nil.') end if @direccion_emisor.nil? invalid_properties.push('invalid value for "direccion_emisor", direccion_emisor cannot be nil.') end pattern = Regexp.new(/^[0-9]{1,20}$/) if !@numero_pedido_interno.nil? && @numero_pedido_interno !~ pattern invalid_properties.push("invalid value for \"numero_pedido_interno\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 390 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
278 279 280 281 282 283 284 285 |
# File 'lib/ecf_dgii/generated/models/ecf34_emisor.rb', line 278 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @rnc_emisor.nil? return false if @razon_social_emisor.nil? return false if @direccion_emisor.nil? return false if !@numero_pedido_interno.nil? && @numero_pedido_interno !~ Regexp.new(/^[0-9]{1,20}$/) true end |