Class: EcfDgii::Generated::Ecf34IdDoc
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf34IdDoc
- Defined in:
- lib/ecf_dgii/generated/models/ecf34_id_doc.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#encf ⇒ Object
Returns the value of attribute encf.
-
#fecha_desde ⇒ Object
Returns the value of attribute fecha_desde.
-
#fecha_hasta ⇒ Object
Returns the value of attribute fecha_hasta.
-
#fecha_limite_pago ⇒ Object
Returns the value of attribute fecha_limite_pago.
-
#indicador_envio_diferido ⇒ Object
Returns the value of attribute indicador_envio_diferido.
-
#indicador_monto_gravado ⇒ Object
Returns the value of attribute indicador_monto_gravado.
-
#indicador_nota_credito ⇒ Object
Returns the value of attribute indicador_nota_credito.
-
#indicador_servicio_todo_incluido ⇒ Object
Returns the value of attribute indicador_servicio_todo_incluido.
-
#tipo_ingresos ⇒ Object
Returns the value of attribute tipo_ingresos.
-
#tipo_pago ⇒ Object
Returns the value of attribute tipo_pago.
-
#tipoe_cf ⇒ Object
Returns the value of attribute tipoe_cf.
-
#total_paginas ⇒ Object
Returns the value of attribute total_paginas.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf34IdDoc
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf34IdDoc
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf34IdDoc` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf34IdDoc`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tipoe_cf') self.tipoe_cf = attributes[:'tipoe_cf'] else self.tipoe_cf = nil end if attributes.key?(:'encf') self.encf = attributes[:'encf'] else self.encf = nil end if attributes.key?(:'indicador_nota_credito') self.indicador_nota_credito = attributes[:'indicador_nota_credito'] else self.indicador_nota_credito = nil end if attributes.key?(:'indicador_envio_diferido') self.indicador_envio_diferido = attributes[:'indicador_envio_diferido'] end if attributes.key?(:'indicador_monto_gravado') self.indicador_monto_gravado = attributes[:'indicador_monto_gravado'] end if attributes.key?(:'indicador_servicio_todo_incluido') self.indicador_servicio_todo_incluido = attributes[:'indicador_servicio_todo_incluido'] end if attributes.key?(:'tipo_ingresos') self.tipo_ingresos = attributes[:'tipo_ingresos'] end if attributes.key?(:'tipo_pago') self.tipo_pago = attributes[:'tipo_pago'] else self.tipo_pago = nil end if attributes.key?(:'fecha_limite_pago') self.fecha_limite_pago = attributes[:'fecha_limite_pago'] end if attributes.key?(:'fecha_desde') self.fecha_desde = attributes[:'fecha_desde'] end if attributes.key?(:'fecha_hasta') self.fecha_hasta = attributes[:'fecha_hasta'] end if attributes.key?(:'total_paginas') self.total_paginas = attributes[:'total_paginas'] end end |
Instance Attribute Details
#encf ⇒ Object
Returns the value of attribute encf.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 20 def encf @encf end |
#fecha_desde ⇒ Object
Returns the value of attribute fecha_desde.
36 37 38 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 36 def fecha_desde @fecha_desde end |
#fecha_hasta ⇒ Object
Returns the value of attribute fecha_hasta.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 38 def fecha_hasta @fecha_hasta end |
#fecha_limite_pago ⇒ Object
Returns the value of attribute fecha_limite_pago.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 34 def fecha_limite_pago @fecha_limite_pago end |
#indicador_envio_diferido ⇒ Object
Returns the value of attribute indicador_envio_diferido.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 24 def indicador_envio_diferido @indicador_envio_diferido end |
#indicador_monto_gravado ⇒ Object
Returns the value of attribute indicador_monto_gravado.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 26 def indicador_monto_gravado @indicador_monto_gravado end |
#indicador_nota_credito ⇒ Object
Returns the value of attribute indicador_nota_credito.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 22 def indicador_nota_credito @indicador_nota_credito end |
#indicador_servicio_todo_incluido ⇒ Object
Returns the value of attribute indicador_servicio_todo_incluido.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 28 def indicador_servicio_todo_incluido @indicador_servicio_todo_incluido end |
#tipo_ingresos ⇒ Object
Returns the value of attribute tipo_ingresos.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 30 def tipo_ingresos @tipo_ingresos end |
#tipo_pago ⇒ Object
Returns the value of attribute tipo_pago.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 32 def tipo_pago @tipo_pago end |
#tipoe_cf ⇒ Object
Returns the value of attribute tipoe_cf.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 18 def tipoe_cf @tipoe_cf end |
#total_paginas ⇒ Object
Returns the value of attribute total_paginas.
40 41 42 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 40 def total_paginas @total_paginas end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 65 def self.attribute_map { :'tipoe_cf' => :'tipoeCF', :'encf' => :'encf', :'indicador_nota_credito' => :'indicadorNotaCredito', :'indicador_envio_diferido' => :'indicadorEnvioDiferido', :'indicador_monto_gravado' => :'indicadorMontoGravado', :'indicador_servicio_todo_incluido' => :'indicadorServicioTodoIncluido', :'tipo_ingresos' => :'tipoIngresos', :'tipo_pago' => :'tipoPago', :'fecha_limite_pago' => :'fechaLimitePago', :'fecha_desde' => :'fechaDesde', :'fecha_hasta' => :'fechaHasta', :'total_paginas' => :'totalPaginas' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 306 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 111 def self.openapi_nullable Set.new([ :'indicador_envio_diferido', :'indicador_monto_gravado', :'indicador_servicio_todo_incluido', :'tipo_ingresos', :'fecha_limite_pago', :'fecha_desde', :'fecha_hasta', :'total_paginas' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 93 def self.openapi_types { :'tipoe_cf' => :'TipoeCFType', :'encf' => :'String', :'indicador_nota_credito' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner', :'indicador_envio_diferido' => :'IndicadorEnvioDiferidoType', :'indicador_monto_gravado' => :'IndicadorMontoGravadoType', :'indicador_servicio_todo_incluido' => :'IndicadorServicioTodoIncluidoType', :'tipo_ingresos' => :'TipoIngresosValidationType', :'tipo_pago' => :'Ecf34TipoPagoType', :'fecha_limite_pago' => :'Time', :'fecha_desde' => :'Time', :'fecha_hasta' => :'Time', :'total_paginas' => :'AcecfSummaryDtoReceptorHttpStatus' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 274 def ==(o) return true if self.equal?(o) self.class == o.class && tipoe_cf == o.tipoe_cf && encf == o.encf && indicador_nota_credito == o.indicador_nota_credito && indicador_envio_diferido == o.indicador_envio_diferido && indicador_monto_gravado == o.indicador_monto_gravado && indicador_servicio_todo_incluido == o.indicador_servicio_todo_incluido && tipo_ingresos == o.tipo_ingresos && tipo_pago == o.tipo_pago && fecha_limite_pago == o.fecha_limite_pago && fecha_desde == o.fecha_desde && fecha_hasta == o.fecha_hasta && total_paginas == o.total_paginas end |
#eql?(o) ⇒ Boolean
293 294 295 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 293 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
299 300 301 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 299 def hash [tipoe_cf, encf, indicador_nota_credito, indicador_envio_diferido, indicador_monto_gravado, indicador_servicio_todo_incluido, tipo_ingresos, tipo_pago, fecha_limite_pago, fecha_desde, fecha_hasta, total_paginas].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 199 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @tipoe_cf.nil? invalid_properties.push('invalid value for "tipoe_cf", tipoe_cf cannot be nil.') end if @encf.nil? invalid_properties.push('invalid value for "encf", encf cannot be nil.') end if @indicador_nota_credito.nil? invalid_properties.push('invalid value for "indicador_nota_credito", indicador_nota_credito cannot be nil.') end if @tipo_pago.nil? invalid_properties.push('invalid value for "tipo_pago", tipo_pago cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 227 228 229 230 |
# File 'lib/ecf_dgii/generated/models/ecf34_id_doc.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @tipoe_cf.nil? return false if @encf.nil? return false if @indicador_nota_credito.nil? return false if @tipo_pago.nil? true end |