Class: EcfDgii::Generated::Ecf41Item

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf41_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf41Item

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 152

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf41Item` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf41Item`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'numero_linea')
    self.numero_linea = attributes[:'numero_linea']
  else
    self.numero_linea = nil
  end

  if attributes.key?(:'tabla_codigos_item')
    if (value = attributes[:'tabla_codigos_item']).is_a?(Array)
      self.tabla_codigos_item = value
    end
  end

  if attributes.key?(:'indicador_facturacion')
    self.indicador_facturacion = attributes[:'indicador_facturacion']
  else
    self.indicador_facturacion = nil
  end

  if attributes.key?(:'retencion')
    self.retencion = attributes[:'retencion']
  else
    self.retencion = nil
  end

  if attributes.key?(:'nombre_item')
    self.nombre_item = attributes[:'nombre_item']
  else
    self.nombre_item = nil
  end

  if attributes.key?(:'indicador_bieno_servicio')
    self.indicador_bieno_servicio = attributes[:'indicador_bieno_servicio']
  else
    self.indicador_bieno_servicio = nil
  end

  if attributes.key?(:'descripcion_item')
    self.descripcion_item = attributes[:'descripcion_item']
  end

  if attributes.key?(:'cantidad_item')
    self.cantidad_item = attributes[:'cantidad_item']
  else
    self.cantidad_item = nil
  end

  if attributes.key?(:'unidad_medida')
    self.unidad_medida = attributes[:'unidad_medida']
  end

  if attributes.key?(:'fecha_elaboracion')
    self.fecha_elaboracion = attributes[:'fecha_elaboracion']
  end

  if attributes.key?(:'fecha_vencimiento_item')
    self.fecha_vencimiento_item = attributes[:'fecha_vencimiento_item']
  end

  if attributes.key?(:'precio_unitario_item')
    self.precio_unitario_item = attributes[:'precio_unitario_item']
  else
    self.precio_unitario_item = nil
  end

  if attributes.key?(:'descuento_monto')
    self.descuento_monto = attributes[:'descuento_monto']
  end

  if attributes.key?(:'tabla_sub_descuento')
    if (value = attributes[:'tabla_sub_descuento']).is_a?(Array)
      self.tabla_sub_descuento = value
    end
  end

  if attributes.key?(:'recargo_monto')
    self.recargo_monto = attributes[:'recargo_monto']
  end

  if attributes.key?(:'tabla_sub_recargo')
    if (value = attributes[:'tabla_sub_recargo']).is_a?(Array)
      self.tabla_sub_recargo = value
    end
  end

  if attributes.key?(:'otra_moneda_detalle')
    self.otra_moneda_detalle = attributes[:'otra_moneda_detalle']
  end

  if attributes.key?(:'monto_item')
    self.monto_item = attributes[:'monto_item']
  else
    self.monto_item = nil
  end
end

Instance Attribute Details

#cantidad_itemObject

Returns the value of attribute cantidad_item.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 32

def cantidad_item
  @cantidad_item
end

#descripcion_itemObject

Returns the value of attribute descripcion_item.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 30

def descripcion_item
  @descripcion_item
end

#descuento_montoObject

Returns the value of attribute descuento_monto.



42
43
44
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 42

def descuento_monto
  @descuento_monto
end

#fecha_elaboracionObject

Returns the value of attribute fecha_elaboracion.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 36

def fecha_elaboracion
  @fecha_elaboracion
end

#fecha_vencimiento_itemObject

Returns the value of attribute fecha_vencimiento_item.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 38

def fecha_vencimiento_item
  @fecha_vencimiento_item
end

#indicador_bieno_servicioObject

Returns the value of attribute indicador_bieno_servicio.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 28

def indicador_bieno_servicio
  @indicador_bieno_servicio
end

#indicador_facturacionObject

Returns the value of attribute indicador_facturacion.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 22

def indicador_facturacion
  @indicador_facturacion
end

#monto_itemObject

Returns the value of attribute monto_item.



52
53
54
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 52

def monto_item
  @monto_item
end

#nombre_itemObject

Returns the value of attribute nombre_item.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 26

def nombre_item
  @nombre_item
end

#numero_lineaObject

Returns the value of attribute numero_linea.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 18

def numero_linea
  @numero_linea
end

#otra_moneda_detalleObject

Returns the value of attribute otra_moneda_detalle.



50
51
52
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 50

def otra_moneda_detalle
  @otra_moneda_detalle
end

#precio_unitario_itemObject

Returns the value of attribute precio_unitario_item.



40
41
42
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 40

def precio_unitario_item
  @precio_unitario_item
end

#recargo_montoObject

Returns the value of attribute recargo_monto.



46
47
48
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 46

def recargo_monto
  @recargo_monto
end

#retencionObject

Returns the value of attribute retencion.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 24

def retencion
  @retencion
end

#tabla_codigos_itemObject

Returns the value of attribute tabla_codigos_item.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 20

def tabla_codigos_item
  @tabla_codigos_item
end

#tabla_sub_descuentoObject

Returns the value of attribute tabla_sub_descuento.



44
45
46
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 44

def tabla_sub_descuento
  @tabla_sub_descuento
end

#tabla_sub_recargoObject

Returns the value of attribute tabla_sub_recargo.



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 48

def tabla_sub_recargo
  @tabla_sub_recargo
end

#unidad_medidaObject

Returns the value of attribute unidad_medida.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 34

def unidad_medida
  @unidad_medida
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



101
102
103
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 101

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



106
107
108
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 106

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 77

def self.attribute_map
  {
    :'numero_linea' => :'numeroLinea',
    :'tabla_codigos_item' => :'tablaCodigosItem',
    :'indicador_facturacion' => :'indicadorFacturacion',
    :'retencion' => :'retencion',
    :'nombre_item' => :'nombreItem',
    :'indicador_bieno_servicio' => :'indicadorBienoServicio',
    :'descripcion_item' => :'descripcionItem',
    :'cantidad_item' => :'cantidadItem',
    :'unidad_medida' => :'unidadMedida',
    :'fecha_elaboracion' => :'fechaElaboracion',
    :'fecha_vencimiento_item' => :'fechaVencimientoItem',
    :'precio_unitario_item' => :'precioUnitarioItem',
    :'descuento_monto' => :'descuentoMonto',
    :'tabla_sub_descuento' => :'tablaSubDescuento',
    :'recargo_monto' => :'recargoMonto',
    :'tabla_sub_recargo' => :'tablaSubRecargo',
    :'otra_moneda_detalle' => :'otraMonedaDetalle',
    :'monto_item' => :'montoItem'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 436

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 135

def self.openapi_nullable
  Set.new([
    :'tabla_codigos_item',
    :'descripcion_item',
    :'unidad_medida',
    :'fecha_elaboracion',
    :'fecha_vencimiento_item',
    :'descuento_monto',
    :'tabla_sub_descuento',
    :'recargo_monto',
    :'tabla_sub_recargo',
    :'otra_moneda_detalle',
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 111

def self.openapi_types
  {
    :'numero_linea' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner',
    :'tabla_codigos_item' => :'Array<Ecf41CodigosItem>',
    :'indicador_facturacion' => :'Ecf41IndicadorFacturacionType',
    :'retencion' => :'Ecf41Retencion',
    :'nombre_item' => :'String',
    :'indicador_bieno_servicio' => :'Ecf41IndicadorBienoServicioType',
    :'descripcion_item' => :'String',
    :'cantidad_item' => :'Ecf31ItemCantidadItem',
    :'unidad_medida' => :'UnidadMedidaType',
    :'fecha_elaboracion' => :'Time',
    :'fecha_vencimiento_item' => :'Time',
    :'precio_unitario_item' => :'Ecf31ItemPrecioUnitarioItem',
    :'descuento_monto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'tabla_sub_descuento' => :'Array<Ecf41SubDescuento>',
    :'recargo_monto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'tabla_sub_recargo' => :'Array<Ecf41SubRecargo>',
    :'otra_moneda_detalle' => :'Ecf41OtraMonedaDetalle',
    :'monto_item' => :'Ecf31FormaDePagoMontoPago'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 398

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      numero_linea == o.numero_linea &&
      tabla_codigos_item == o.tabla_codigos_item &&
      indicador_facturacion == o.indicador_facturacion &&
      retencion == o.retencion &&
      nombre_item == o.nombre_item &&
      indicador_bieno_servicio == o.indicador_bieno_servicio &&
      descripcion_item == o.descripcion_item &&
      cantidad_item == o.cantidad_item &&
      unidad_medida == o.unidad_medida &&
      fecha_elaboracion == o.fecha_elaboracion &&
      fecha_vencimiento_item == o.fecha_vencimiento_item &&
      precio_unitario_item == o.precio_unitario_item &&
      descuento_monto == o.descuento_monto &&
      tabla_sub_descuento == o.tabla_sub_descuento &&
      recargo_monto == o.recargo_monto &&
      tabla_sub_recargo == o.tabla_sub_recargo &&
      otra_moneda_detalle == o.otra_moneda_detalle &&
      monto_item == o.monto_item
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


423
424
425
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 423

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



429
430
431
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 429

def hash
  [numero_linea, tabla_codigos_item, indicador_facturacion, retencion, nombre_item, indicador_bieno_servicio, descripcion_item, cantidad_item, unidad_medida, fecha_elaboracion, fecha_vencimiento_item, precio_unitario_item, descuento_monto, tabla_sub_descuento, recargo_monto, tabla_sub_recargo, otra_moneda_detalle, monto_item].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 263

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @numero_linea.nil?
    invalid_properties.push('invalid value for "numero_linea", numero_linea cannot be nil.')
  end

  if @indicador_facturacion.nil?
    invalid_properties.push('invalid value for "indicador_facturacion", indicador_facturacion cannot be nil.')
  end

  if @retencion.nil?
    invalid_properties.push('invalid value for "retencion", retencion cannot be nil.')
  end

  if @nombre_item.nil?
    invalid_properties.push('invalid value for "nombre_item", nombre_item cannot be nil.')
  end

  if @indicador_bieno_servicio.nil?
    invalid_properties.push('invalid value for "indicador_bieno_servicio", indicador_bieno_servicio cannot be nil.')
  end

  if @cantidad_item.nil?
    invalid_properties.push('invalid value for "cantidad_item", cantidad_item cannot be nil.')
  end

  if @precio_unitario_item.nil?
    invalid_properties.push('invalid value for "precio_unitario_item", precio_unitario_item cannot be nil.')
  end

  if @monto_item.nil?
    invalid_properties.push('invalid value for "monto_item", monto_item cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 458

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/ecf_dgii/generated/models/ecf41_item.rb', line 303

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @numero_linea.nil?
  return false if @indicador_facturacion.nil?
  return false if @retencion.nil?
  return false if @nombre_item.nil?
  return false if @indicador_bieno_servicio.nil?
  return false if @cantidad_item.nil?
  return false if @precio_unitario_item.nil?
  return false if @monto_item.nil?
  true
end