Class: EcfDgii::Generated::Ecf41Totales

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf41_totales.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf41Totales

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 152

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf41Totales` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf41Totales`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'monto_gravado_total')
    self.monto_gravado_total = attributes[:'monto_gravado_total']
  end

  if attributes.key?(:'monto_gravado_i1')
    self.monto_gravado_i1 = attributes[:'monto_gravado_i1']
  end

  if attributes.key?(:'monto_gravado_i2')
    self.monto_gravado_i2 = attributes[:'monto_gravado_i2']
  end

  if attributes.key?(:'monto_gravado_i3')
    self.monto_gravado_i3 = attributes[:'monto_gravado_i3']
  end

  if attributes.key?(:'monto_exento')
    self.monto_exento = attributes[:'monto_exento']
  end

  if attributes.key?(:'itbi_s1')
    self.itbi_s1 = attributes[:'itbi_s1']
  end

  if attributes.key?(:'itbi_s2')
    self.itbi_s2 = attributes[:'itbi_s2']
  end

  if attributes.key?(:'itbi_s3')
    self.itbi_s3 = attributes[:'itbi_s3']
  end

  if attributes.key?(:'total_itbis')
    self.total_itbis = attributes[:'total_itbis']
  end

  if attributes.key?(:'total_itbis1')
    self.total_itbis1 = attributes[:'total_itbis1']
  end

  if attributes.key?(:'total_itbis2')
    self.total_itbis2 = attributes[:'total_itbis2']
  end

  if attributes.key?(:'total_itbis3')
    self.total_itbis3 = attributes[:'total_itbis3']
  end

  if attributes.key?(:'monto_total')
    self.monto_total = attributes[:'monto_total']
  else
    self.monto_total = nil
  end

  if attributes.key?(:'monto_periodo')
    self.monto_periodo = attributes[:'monto_periodo']
  end

  if attributes.key?(:'saldo_anterior')
    self.saldo_anterior = attributes[:'saldo_anterior']
  end

  if attributes.key?(:'monto_avance_pago')
    self.monto_avance_pago = attributes[:'monto_avance_pago']
  end

  if attributes.key?(:'valor_pagar')
    self.valor_pagar = attributes[:'valor_pagar']
  end

  if attributes.key?(:'total_itbis_retenido')
    self.total_itbis_retenido = attributes[:'total_itbis_retenido']
  end

  if attributes.key?(:'total_isr_retencion')
    self.total_isr_retencion = attributes[:'total_isr_retencion']
  end

  if attributes.key?(:'total_itbis_percepcion')
    self.total_itbis_percepcion = attributes[:'total_itbis_percepcion']
  end

  if attributes.key?(:'total_isr_percepcion')
    self.total_isr_percepcion = attributes[:'total_isr_percepcion']
  end
end

Instance Attribute Details

#itbi_s1Object

Returns the value of attribute itbi_s1.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 28

def itbi_s1
  @itbi_s1
end

#itbi_s2Object

Returns the value of attribute itbi_s2.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 30

def itbi_s2
  @itbi_s2
end

#itbi_s3Object

Returns the value of attribute itbi_s3.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 32

def itbi_s3
  @itbi_s3
end

#monto_avance_pagoObject

Returns the value of attribute monto_avance_pago.



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 48

def monto_avance_pago
  @monto_avance_pago
end

#monto_exentoObject

Returns the value of attribute monto_exento.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 26

def monto_exento
  @monto_exento
end

#monto_gravado_i1Object

Returns the value of attribute monto_gravado_i1.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 20

def monto_gravado_i1
  @monto_gravado_i1
end

#monto_gravado_i2Object

Returns the value of attribute monto_gravado_i2.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 22

def monto_gravado_i2
  @monto_gravado_i2
end

#monto_gravado_i3Object

Returns the value of attribute monto_gravado_i3.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 24

def monto_gravado_i3
  @monto_gravado_i3
end

#monto_gravado_totalObject

Returns the value of attribute monto_gravado_total.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 18

def monto_gravado_total
  @monto_gravado_total
end

#monto_periodoObject

Returns the value of attribute monto_periodo.



44
45
46
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 44

def monto_periodo
  @monto_periodo
end

#monto_totalObject

Returns the value of attribute monto_total.



42
43
44
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 42

def monto_total
  @monto_total
end

#saldo_anteriorObject

Returns the value of attribute saldo_anterior.



46
47
48
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 46

def saldo_anterior
  @saldo_anterior
end

#total_isr_percepcionObject

Returns the value of attribute total_isr_percepcion.



58
59
60
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 58

def total_isr_percepcion
  @total_isr_percepcion
end

#total_isr_retencionObject

Returns the value of attribute total_isr_retencion.



54
55
56
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 54

def total_isr_retencion
  @total_isr_retencion
end

#total_itbisObject

Returns the value of attribute total_itbis.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 34

def total_itbis
  @total_itbis
end

#total_itbis1Object

Returns the value of attribute total_itbis1.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 36

def total_itbis1
  @total_itbis1
end

#total_itbis2Object

Returns the value of attribute total_itbis2.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 38

def total_itbis2
  @total_itbis2
end

#total_itbis3Object

Returns the value of attribute total_itbis3.



40
41
42
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 40

def total_itbis3
  @total_itbis3
end

#total_itbis_percepcionObject

Returns the value of attribute total_itbis_percepcion.



56
57
58
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 56

def total_itbis_percepcion
  @total_itbis_percepcion
end

#total_itbis_retenidoObject

Returns the value of attribute total_itbis_retenido.



52
53
54
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 52

def total_itbis_retenido
  @total_itbis_retenido
end

#valor_pagarObject

Returns the value of attribute valor_pagar.



50
51
52
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 50

def valor_pagar
  @valor_pagar
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 61

def self.attribute_map
  {
    :'monto_gravado_total' => :'montoGravadoTotal',
    :'monto_gravado_i1' => :'montoGravadoI1',
    :'monto_gravado_i2' => :'montoGravadoI2',
    :'monto_gravado_i3' => :'montoGravadoI3',
    :'monto_exento' => :'montoExento',
    :'itbi_s1' => :'itbiS1',
    :'itbi_s2' => :'itbiS2',
    :'itbi_s3' => :'itbiS3',
    :'total_itbis' => :'totalITBIS',
    :'total_itbis1' => :'totalITBIS1',
    :'total_itbis2' => :'totalITBIS2',
    :'total_itbis3' => :'totalITBIS3',
    :'monto_total' => :'montoTotal',
    :'monto_periodo' => :'montoPeriodo',
    :'saldo_anterior' => :'saldoAnterior',
    :'monto_avance_pago' => :'montoAvancePago',
    :'valor_pagar' => :'valorPagar',
    :'total_itbis_retenido' => :'totalITBISRetenido',
    :'total_isr_retencion' => :'totalISRRetencion',
    :'total_itbis_percepcion' => :'totalITBISPercepcion',
    :'total_isr_percepcion' => :'totalISRPercepcion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 326

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 125

def self.openapi_nullable
  Set.new([
    :'monto_gravado_total',
    :'monto_gravado_i1',
    :'monto_gravado_i2',
    :'monto_gravado_i3',
    :'monto_exento',
    :'itbi_s1',
    :'itbi_s2',
    :'itbi_s3',
    :'total_itbis',
    :'total_itbis1',
    :'total_itbis2',
    :'total_itbis3',
    :'monto_periodo',
    :'saldo_anterior',
    :'monto_avance_pago',
    :'valor_pagar',
    :'total_itbis_retenido',
    :'total_isr_retencion',
    :'total_itbis_percepcion',
    :'total_isr_percepcion'
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 98

def self.openapi_types
  {
    :'monto_gravado_total' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_gravado_i1' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_gravado_i2' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_gravado_i3' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_exento' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'itbi_s1' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'itbi_s2' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'itbi_s3' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'total_itbis' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_itbis1' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_itbis2' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_itbis3' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_total' => :'Ecf31FormaDePagoMontoPago',
    :'monto_periodo' => :'Ecf31TotalesMontoNoFacturable',
    :'saldo_anterior' => :'Ecf31TotalesMontoNoFacturable',
    :'monto_avance_pago' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'valor_pagar' => :'Ecf31TotalesMontoNoFacturable',
    :'total_itbis_retenido' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_isr_retencion' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_itbis_percepcion' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_isr_percepcion' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 285

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      monto_gravado_total == o.monto_gravado_total &&
      monto_gravado_i1 == o.monto_gravado_i1 &&
      monto_gravado_i2 == o.monto_gravado_i2 &&
      monto_gravado_i3 == o.monto_gravado_i3 &&
      monto_exento == o.monto_exento &&
      itbi_s1 == o.itbi_s1 &&
      itbi_s2 == o.itbi_s2 &&
      itbi_s3 == o.itbi_s3 &&
      total_itbis == o.total_itbis &&
      total_itbis1 == o.total_itbis1 &&
      total_itbis2 == o.total_itbis2 &&
      total_itbis3 == o.total_itbis3 &&
      monto_total == o.monto_total &&
      monto_periodo == o.monto_periodo &&
      saldo_anterior == o.saldo_anterior &&
      monto_avance_pago == o.monto_avance_pago &&
      valor_pagar == o.valor_pagar &&
      total_itbis_retenido == o.total_itbis_retenido &&
      total_isr_retencion == o.total_isr_retencion &&
      total_itbis_percepcion == o.total_itbis_percepcion &&
      total_isr_percepcion == o.total_isr_percepcion
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


313
314
315
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 313

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



319
320
321
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 319

def hash
  [monto_gravado_total, monto_gravado_i1, monto_gravado_i2, monto_gravado_i3, monto_exento, itbi_s1, itbi_s2, itbi_s3, total_itbis, total_itbis1, total_itbis2, total_itbis3, monto_total, monto_periodo, saldo_anterior, monto_avance_pago, valor_pagar, total_itbis_retenido, total_isr_retencion, total_itbis_percepcion, total_isr_percepcion].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



255
256
257
258
259
260
261
262
263
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 255

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @monto_total.nil?
    invalid_properties.push('invalid value for "monto_total", monto_total cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 348

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



267
268
269
270
271
# File 'lib/ecf_dgii/generated/models/ecf41_totales.rb', line 267

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @monto_total.nil?
  true
end