Class: EcfDgii::Generated::Ecf43Emisor

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf43_emisor.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf43Emisor

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf43Emisor` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf43Emisor`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rnc_emisor')
    self.rnc_emisor = attributes[:'rnc_emisor']
  else
    self.rnc_emisor = nil
  end

  if attributes.key?(:'razon_social_emisor')
    self.razon_social_emisor = attributes[:'razon_social_emisor']
  else
    self.razon_social_emisor = nil
  end

  if attributes.key?(:'nombre_comercial')
    self.nombre_comercial = attributes[:'nombre_comercial']
  end

  if attributes.key?(:'sucursal')
    self.sucursal = attributes[:'sucursal']
  end

  if attributes.key?(:'direccion_emisor')
    self.direccion_emisor = attributes[:'direccion_emisor']
  else
    self.direccion_emisor = nil
  end

  if attributes.key?(:'municipio')
    self.municipio = attributes[:'municipio']
  end

  if attributes.key?(:'provincia')
    self.provincia = attributes[:'provincia']
  end

  if attributes.key?(:'tabla_telefono_emisor')
    if (value = attributes[:'tabla_telefono_emisor']).is_a?(Array)
      self.tabla_telefono_emisor = value
    end
  end

  if attributes.key?(:'correo_emisor')
    self.correo_emisor = attributes[:'correo_emisor']
  end

  if attributes.key?(:'web_site')
    self.web_site = attributes[:'web_site']
  end

  if attributes.key?(:'actividad_economica')
    self.actividad_economica = attributes[:'actividad_economica']
  end

  if attributes.key?(:'numero_factura_interna')
    self.numero_factura_interna = attributes[:'numero_factura_interna']
  end

  if attributes.key?(:'numero_pedido_interno')
    self.numero_pedido_interno = attributes[:'numero_pedido_interno']
  end

  if attributes.key?(:'informacion_adicional_emisor')
    self.informacion_adicional_emisor = attributes[:'informacion_adicional_emisor']
  end

  if attributes.key?(:'fecha_emision')
    self.fecha_emision = attributes[:'fecha_emision']
  end
end

Instance Attribute Details

#actividad_economicaObject

Returns the value of attribute actividad_economica.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 38

def actividad_economica
  @actividad_economica
end

#correo_emisorObject

Returns the value of attribute correo_emisor.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 34

def correo_emisor
  @correo_emisor
end

#direccion_emisorObject

Returns the value of attribute direccion_emisor.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 26

def direccion_emisor
  @direccion_emisor
end

#fecha_emisionObject

Returns the value of attribute fecha_emision.



46
47
48
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 46

def fecha_emision
  @fecha_emision
end

#informacion_adicional_emisorObject

Returns the value of attribute informacion_adicional_emisor.



44
45
46
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 44

def informacion_adicional_emisor
  @informacion_adicional_emisor
end

#municipioObject

Returns the value of attribute municipio.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 28

def municipio
  @municipio
end

#nombre_comercialObject

Returns the value of attribute nombre_comercial.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 22

def nombre_comercial
  @nombre_comercial
end

#numero_factura_internaObject

Returns the value of attribute numero_factura_interna.



40
41
42
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 40

def numero_factura_interna
  @numero_factura_interna
end

#numero_pedido_internoObject

Returns the value of attribute numero_pedido_interno.



42
43
44
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 42

def numero_pedido_interno
  @numero_pedido_interno
end

#provinciaObject

Returns the value of attribute provincia.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 30

def provincia
  @provincia
end

#razon_social_emisorObject

Returns the value of attribute razon_social_emisor.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 20

def razon_social_emisor
  @razon_social_emisor
end

#rnc_emisorObject

Returns the value of attribute rnc_emisor.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 18

def rnc_emisor
  @rnc_emisor
end

#sucursalObject

Returns the value of attribute sucursal.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 24

def sucursal
  @sucursal
end

#tabla_telefono_emisorObject

Returns the value of attribute tabla_telefono_emisor.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 32

def tabla_telefono_emisor
  @tabla_telefono_emisor
end

#web_siteObject

Returns the value of attribute web_site.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 36

def web_site
  @web_site
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 71

def self.attribute_map
  {
    :'rnc_emisor' => :'rncEmisor',
    :'razon_social_emisor' => :'razonSocialEmisor',
    :'nombre_comercial' => :'nombreComercial',
    :'sucursal' => :'sucursal',
    :'direccion_emisor' => :'direccionEmisor',
    :'municipio' => :'municipio',
    :'provincia' => :'provincia',
    :'tabla_telefono_emisor' => :'tablaTelefonoEmisor',
    :'correo_emisor' => :'correoEmisor',
    :'web_site' => :'webSite',
    :'actividad_economica' => :'actividadEconomica',
    :'numero_factura_interna' => :'numeroFacturaInterna',
    :'numero_pedido_interno' => :'numeroPedidoInterno',
    :'informacion_adicional_emisor' => :'informacionAdicionalEmisor',
    :'fecha_emision' => :'fechaEmision'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 338

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 123

def self.openapi_nullable
  Set.new([
    :'nombre_comercial',
    :'sucursal',
    :'municipio',
    :'provincia',
    :'tabla_telefono_emisor',
    :'correo_emisor',
    :'web_site',
    :'actividad_economica',
    :'numero_factura_interna',
    :'numero_pedido_interno',
    :'informacion_adicional_emisor',
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 102

def self.openapi_types
  {
    :'rnc_emisor' => :'String',
    :'razon_social_emisor' => :'String',
    :'nombre_comercial' => :'String',
    :'sucursal' => :'String',
    :'direccion_emisor' => :'String',
    :'municipio' => :'ProvinciaMunicipioType',
    :'provincia' => :'ProvinciaMunicipioType',
    :'tabla_telefono_emisor' => :'Array<String>',
    :'correo_emisor' => :'String',
    :'web_site' => :'String',
    :'actividad_economica' => :'String',
    :'numero_factura_interna' => :'String',
    :'numero_pedido_interno' => :'String',
    :'informacion_adicional_emisor' => :'String',
    :'fecha_emision' => :'Date'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 303

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rnc_emisor == o.rnc_emisor &&
      razon_social_emisor == o.razon_social_emisor &&
      nombre_comercial == o.nombre_comercial &&
      sucursal == o.sucursal &&
      direccion_emisor == o.direccion_emisor &&
      municipio == o.municipio &&
      provincia == o.provincia &&
      tabla_telefono_emisor == o.tabla_telefono_emisor &&
      correo_emisor == o.correo_emisor &&
      web_site == o.web_site &&
      actividad_economica == o.actividad_economica &&
      numero_factura_interna == o.numero_factura_interna &&
      numero_pedido_interno == o.numero_pedido_interno &&
      informacion_adicional_emisor == o.informacion_adicional_emisor &&
      fecha_emision == o.fecha_emision
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


325
326
327
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 325

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



331
332
333
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 331

def hash
  [rnc_emisor, razon_social_emisor, nombre_comercial, sucursal, direccion_emisor, municipio, provincia, tabla_telefono_emisor, correo_emisor, web_site, actividad_economica, numero_factura_interna, numero_pedido_interno, informacion_adicional_emisor, fecha_emision].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 226

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @rnc_emisor.nil?
    invalid_properties.push('invalid value for "rnc_emisor", rnc_emisor cannot be nil.')
  end

  if @razon_social_emisor.nil?
    invalid_properties.push('invalid value for "razon_social_emisor", razon_social_emisor cannot be nil.')
  end

  if @direccion_emisor.nil?
    invalid_properties.push('invalid value for "direccion_emisor", direccion_emisor cannot be nil.')
  end

  pattern = Regexp.new(/^[0-9]{1,20}$/)
  if !@numero_pedido_interno.nil? && @numero_pedido_interno !~ pattern
    invalid_properties.push("invalid value for \"numero_pedido_interno\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 360

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



251
252
253
254
255
256
257
258
# File 'lib/ecf_dgii/generated/models/ecf43_emisor.rb', line 251

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @rnc_emisor.nil?
  return false if @razon_social_emisor.nil?
  return false if @direccion_emisor.nil?
  return false if !@numero_pedido_interno.nil? && @numero_pedido_interno !~ Regexp.new(/^[0-9]{1,20}$/)
  true
end