Class: EcfDgii::Generated::Ecf43Item

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf43_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf43Item

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf43Item` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf43Item`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'numero_linea')
    self.numero_linea = attributes[:'numero_linea']
  else
    self.numero_linea = nil
  end

  if attributes.key?(:'tabla_codigos_item')
    if (value = attributes[:'tabla_codigos_item']).is_a?(Array)
      self.tabla_codigos_item = value
    end
  end

  if attributes.key?(:'indicador_facturacion')
    self.indicador_facturacion = attributes[:'indicador_facturacion']
  else
    self.indicador_facturacion = nil
  end

  if attributes.key?(:'nombre_item')
    self.nombre_item = attributes[:'nombre_item']
  else
    self.nombre_item = nil
  end

  if attributes.key?(:'indicador_bieno_servicio')
    self.indicador_bieno_servicio = attributes[:'indicador_bieno_servicio']
  else
    self.indicador_bieno_servicio = nil
  end

  if attributes.key?(:'descripcion_item')
    self.descripcion_item = attributes[:'descripcion_item']
  end

  if attributes.key?(:'cantidad_item')
    self.cantidad_item = attributes[:'cantidad_item']
  else
    self.cantidad_item = nil
  end

  if attributes.key?(:'unidad_medida')
    self.unidad_medida = attributes[:'unidad_medida']
  end

  if attributes.key?(:'precio_unitario_item')
    self.precio_unitario_item = attributes[:'precio_unitario_item']
  else
    self.precio_unitario_item = nil
  end

  if attributes.key?(:'otra_moneda_detalle')
    self.otra_moneda_detalle = attributes[:'otra_moneda_detalle']
  end

  if attributes.key?(:'monto_item')
    self.monto_item = attributes[:'monto_item']
  else
    self.monto_item = nil
  end
end

Instance Attribute Details

#cantidad_itemObject

Returns the value of attribute cantidad_item.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 30

def cantidad_item
  @cantidad_item
end

#descripcion_itemObject

Returns the value of attribute descripcion_item.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 28

def descripcion_item
  @descripcion_item
end

#indicador_bieno_servicioObject

Returns the value of attribute indicador_bieno_servicio.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 26

def indicador_bieno_servicio
  @indicador_bieno_servicio
end

#indicador_facturacionObject

Returns the value of attribute indicador_facturacion.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 22

def indicador_facturacion
  @indicador_facturacion
end

#monto_itemObject

Returns the value of attribute monto_item.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 38

def monto_item
  @monto_item
end

#nombre_itemObject

Returns the value of attribute nombre_item.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 24

def nombre_item
  @nombre_item
end

#numero_lineaObject

Returns the value of attribute numero_linea.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 18

def numero_linea
  @numero_linea
end

#otra_moneda_detalleObject

Returns the value of attribute otra_moneda_detalle.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 36

def otra_moneda_detalle
  @otra_moneda_detalle
end

#precio_unitario_itemObject

Returns the value of attribute precio_unitario_item.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 34

def precio_unitario_item
  @precio_unitario_item
end

#tabla_codigos_itemObject

Returns the value of attribute tabla_codigos_item.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 20

def tabla_codigos_item
  @tabla_codigos_item
end

#unidad_medidaObject

Returns the value of attribute unidad_medida.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 32

def unidad_medida
  @unidad_medida
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 63

def self.attribute_map
  {
    :'numero_linea' => :'numeroLinea',
    :'tabla_codigos_item' => :'tablaCodigosItem',
    :'indicador_facturacion' => :'indicadorFacturacion',
    :'nombre_item' => :'nombreItem',
    :'indicador_bieno_servicio' => :'indicadorBienoServicio',
    :'descripcion_item' => :'descripcionItem',
    :'cantidad_item' => :'cantidadItem',
    :'unidad_medida' => :'unidadMedida',
    :'precio_unitario_item' => :'precioUnitarioItem',
    :'otra_moneda_detalle' => :'otraMonedaDetalle',
    :'monto_item' => :'montoItem'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 346

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
114
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 107

def self.openapi_nullable
  Set.new([
    :'tabla_codigos_item',
    :'descripcion_item',
    :'unidad_medida',
    :'otra_moneda_detalle',
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 90

def self.openapi_types
  {
    :'numero_linea' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner',
    :'tabla_codigos_item' => :'Array<Ecf43CodigosItem>',
    :'indicador_facturacion' => :'Ecf43IndicadorFacturacionType',
    :'nombre_item' => :'String',
    :'indicador_bieno_servicio' => :'Ecf43IndicadorBienoServicioType',
    :'descripcion_item' => :'String',
    :'cantidad_item' => :'Ecf31ItemCantidadItem',
    :'unidad_medida' => :'UnidadMedidaType',
    :'precio_unitario_item' => :'Ecf31ItemPrecioUnitarioItem',
    :'otra_moneda_detalle' => :'Ecf43OtraMonedaDetalle',
    :'monto_item' => :'Ecf31FormaDePagoMontoPago'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 315

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      numero_linea == o.numero_linea &&
      tabla_codigos_item == o.tabla_codigos_item &&
      indicador_facturacion == o.indicador_facturacion &&
      nombre_item == o.nombre_item &&
      indicador_bieno_servicio == o.indicador_bieno_servicio &&
      descripcion_item == o.descripcion_item &&
      cantidad_item == o.cantidad_item &&
      unidad_medida == o.unidad_medida &&
      precio_unitario_item == o.precio_unitario_item &&
      otra_moneda_detalle == o.otra_moneda_detalle &&
      monto_item == o.monto_item
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


333
334
335
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 333

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



339
340
341
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 339

def hash
  [numero_linea, tabla_codigos_item, indicador_facturacion, nombre_item, indicador_bieno_servicio, descripcion_item, cantidad_item, unidad_medida, precio_unitario_item, otra_moneda_detalle, monto_item].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @numero_linea.nil?
    invalid_properties.push('invalid value for "numero_linea", numero_linea cannot be nil.')
  end

  if @indicador_facturacion.nil?
    invalid_properties.push('invalid value for "indicador_facturacion", indicador_facturacion cannot be nil.')
  end

  if @nombre_item.nil?
    invalid_properties.push('invalid value for "nombre_item", nombre_item cannot be nil.')
  end

  if @indicador_bieno_servicio.nil?
    invalid_properties.push('invalid value for "indicador_bieno_servicio", indicador_bieno_servicio cannot be nil.')
  end

  if @cantidad_item.nil?
    invalid_properties.push('invalid value for "cantidad_item", cantidad_item cannot be nil.')
  end

  if @precio_unitario_item.nil?
    invalid_properties.push('invalid value for "precio_unitario_item", precio_unitario_item cannot be nil.')
  end

  if @monto_item.nil?
    invalid_properties.push('invalid value for "monto_item", monto_item cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
237
238
239
240
241
# File 'lib/ecf_dgii/generated/models/ecf43_item.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @numero_linea.nil?
  return false if @indicador_facturacion.nil?
  return false if @nombre_item.nil?
  return false if @indicador_bieno_servicio.nil?
  return false if @cantidad_item.nil?
  return false if @precio_unitario_item.nil?
  return false if @monto_item.nil?
  true
end