Class: EcfDgii::Generated::Ecf43Totales

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf43_totales.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf43Totales

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf43Totales` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf43Totales`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'monto_exento')
    self.monto_exento = attributes[:'monto_exento']
  end

  if attributes.key?(:'monto_total')
    self.monto_total = attributes[:'monto_total']
  else
    self.monto_total = nil
  end

  if attributes.key?(:'monto_periodo')
    self.monto_periodo = attributes[:'monto_periodo']
  end

  if attributes.key?(:'saldo_anterior')
    self.saldo_anterior = attributes[:'saldo_anterior']
  end

  if attributes.key?(:'monto_avance_pago')
    self.monto_avance_pago = attributes[:'monto_avance_pago']
  end

  if attributes.key?(:'valor_pagar')
    self.valor_pagar = attributes[:'valor_pagar']
  end
end

Instance Attribute Details

#monto_avance_pagoObject

Returns the value of attribute monto_avance_pago.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 26

def monto_avance_pago
  @monto_avance_pago
end

#monto_exentoObject

Returns the value of attribute monto_exento.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 18

def monto_exento
  @monto_exento
end

#monto_periodoObject

Returns the value of attribute monto_periodo.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 22

def monto_periodo
  @monto_periodo
end

#monto_totalObject

Returns the value of attribute monto_total.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 20

def monto_total
  @monto_total
end

#saldo_anteriorObject

Returns the value of attribute saldo_anterior.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 24

def saldo_anterior
  @saldo_anterior
end

#valor_pagarObject

Returns the value of attribute valor_pagar.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 28

def valor_pagar
  @valor_pagar
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 31

def self.attribute_map
  {
    :'monto_exento' => :'montoExento',
    :'monto_total' => :'montoTotal',
    :'monto_periodo' => :'montoPeriodo',
    :'saldo_anterior' => :'saldoAnterior',
    :'monto_avance_pago' => :'montoAvancePago',
    :'valor_pagar' => :'valorPagar'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
71
72
73
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 65

def self.openapi_nullable
  Set.new([
    :'monto_exento',
    :'monto_periodo',
    :'saldo_anterior',
    :'monto_avance_pago',
    :'valor_pagar'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 53

def self.openapi_types
  {
    :'monto_exento' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_total' => :'Ecf31FormaDePagoMontoPago',
    :'monto_periodo' => :'Ecf31TotalesMontoNoFacturable',
    :'saldo_anterior' => :'Ecf31TotalesMontoNoFacturable',
    :'monto_avance_pago' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'valor_pagar' => :'Ecf31TotalesMontoNoFacturable'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



150
151
152
153
154
155
156
157
158
159
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 150

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      monto_exento == o.monto_exento &&
      monto_total == o.monto_total &&
      monto_periodo == o.monto_periodo &&
      saldo_anterior == o.saldo_anterior &&
      monto_avance_pago == o.monto_avance_pago &&
      valor_pagar == o.valor_pagar
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 169

def hash
  [monto_exento, monto_total, monto_periodo, saldo_anterior, monto_avance_pago, valor_pagar].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @monto_total.nil?
    invalid_properties.push('invalid value for "monto_total", monto_total cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
# File 'lib/ecf_dgii/generated/models/ecf43_totales.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @monto_total.nil?
  true
end