Class: EcfDgii::Generated::Ecf44InformacionesAdicionales
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf44InformacionesAdicionales
- Defined in:
- lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cantidad_bulto ⇒ Object
Returns the value of attribute cantidad_bulto.
-
#fecha_embarque ⇒ Object
Returns the value of attribute fecha_embarque.
-
#numero_contenedor ⇒ Object
Returns the value of attribute numero_contenedor.
-
#numero_embarque ⇒ Object
Returns the value of attribute numero_embarque.
-
#numero_referencia ⇒ Object
Returns the value of attribute numero_referencia.
-
#peso_bruto ⇒ Object
Returns the value of attribute peso_bruto.
-
#peso_neto ⇒ Object
Returns the value of attribute peso_neto.
-
#unidad_bulto ⇒ Object
Returns the value of attribute unidad_bulto.
-
#unidad_peso_bruto ⇒ Object
Returns the value of attribute unidad_peso_bruto.
-
#unidad_peso_neto ⇒ Object
Returns the value of attribute unidad_peso_neto.
-
#unidad_volumen ⇒ Object
Returns the value of attribute unidad_volumen.
-
#volumen_bulto ⇒ Object
Returns the value of attribute volumen_bulto.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf44InformacionesAdicionales
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf44InformacionesAdicionales
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf44InformacionesAdicionales` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf44InformacionesAdicionales`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'fecha_embarque') self. = attributes[:'fecha_embarque'] end if attributes.key?(:'numero_embarque') self. = attributes[:'numero_embarque'] end if attributes.key?(:'numero_contenedor') self.numero_contenedor = attributes[:'numero_contenedor'] end if attributes.key?(:'numero_referencia') self.numero_referencia = attributes[:'numero_referencia'] end if attributes.key?(:'peso_bruto') self.peso_bruto = attributes[:'peso_bruto'] end if attributes.key?(:'peso_neto') self.peso_neto = attributes[:'peso_neto'] end if attributes.key?(:'unidad_peso_bruto') self.unidad_peso_bruto = attributes[:'unidad_peso_bruto'] end if attributes.key?(:'unidad_peso_neto') self.unidad_peso_neto = attributes[:'unidad_peso_neto'] end if attributes.key?(:'cantidad_bulto') self.cantidad_bulto = attributes[:'cantidad_bulto'] end if attributes.key?(:'unidad_bulto') self.unidad_bulto = attributes[:'unidad_bulto'] end if attributes.key?(:'volumen_bulto') self.volumen_bulto = attributes[:'volumen_bulto'] end if attributes.key?(:'unidad_volumen') self.unidad_volumen = attributes[:'unidad_volumen'] end end |
Instance Attribute Details
#cantidad_bulto ⇒ Object
Returns the value of attribute cantidad_bulto.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 34 def cantidad_bulto @cantidad_bulto end |
#fecha_embarque ⇒ Object
Returns the value of attribute fecha_embarque.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 18 def @fecha_embarque end |
#numero_contenedor ⇒ Object
Returns the value of attribute numero_contenedor.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 22 def numero_contenedor @numero_contenedor end |
#numero_embarque ⇒ Object
Returns the value of attribute numero_embarque.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 20 def @numero_embarque end |
#numero_referencia ⇒ Object
Returns the value of attribute numero_referencia.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 24 def numero_referencia @numero_referencia end |
#peso_bruto ⇒ Object
Returns the value of attribute peso_bruto.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 26 def peso_bruto @peso_bruto end |
#peso_neto ⇒ Object
Returns the value of attribute peso_neto.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 28 def peso_neto @peso_neto end |
#unidad_bulto ⇒ Object
Returns the value of attribute unidad_bulto.
36 37 38 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 36 def unidad_bulto @unidad_bulto end |
#unidad_peso_bruto ⇒ Object
Returns the value of attribute unidad_peso_bruto.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 30 def unidad_peso_bruto @unidad_peso_bruto end |
#unidad_peso_neto ⇒ Object
Returns the value of attribute unidad_peso_neto.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 32 def unidad_peso_neto @unidad_peso_neto end |
#unidad_volumen ⇒ Object
Returns the value of attribute unidad_volumen.
40 41 42 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 40 def unidad_volumen @unidad_volumen end |
#volumen_bulto ⇒ Object
Returns the value of attribute volumen_bulto.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 38 def volumen_bulto @volumen_bulto end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 65 def self.attribute_map { :'fecha_embarque' => :'fechaEmbarque', :'numero_embarque' => :'numeroEmbarque', :'numero_contenedor' => :'numeroContenedor', :'numero_referencia' => :'numeroReferencia', :'peso_bruto' => :'pesoBruto', :'peso_neto' => :'pesoNeto', :'unidad_peso_bruto' => :'unidadPesoBruto', :'unidad_peso_neto' => :'unidadPesoNeto', :'cantidad_bulto' => :'cantidadBulto', :'unidad_bulto' => :'unidadBulto', :'volumen_bulto' => :'volumenBulto', :'unidad_volumen' => :'unidadVolumen' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 259 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 111 def self.openapi_nullable Set.new([ :'fecha_embarque', :'numero_embarque', :'numero_contenedor', :'numero_referencia', :'peso_bruto', :'peso_neto', :'unidad_peso_bruto', :'unidad_peso_neto', :'cantidad_bulto', :'unidad_bulto', :'volumen_bulto', :'unidad_volumen' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 93 def self.openapi_types { :'fecha_embarque' => :'Time', :'numero_embarque' => :'String', :'numero_contenedor' => :'String', :'numero_referencia' => :'String', :'peso_bruto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'peso_neto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'unidad_peso_bruto' => :'UnidadMedidaType', :'unidad_peso_neto' => :'UnidadMedidaType', :'cantidad_bulto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'unidad_bulto' => :'UnidadMedidaType', :'volumen_bulto' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico', :'unidad_volumen' => :'UnidadMedidaType' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && == o. && numero_contenedor == o.numero_contenedor && numero_referencia == o.numero_referencia && peso_bruto == o.peso_bruto && peso_neto == o.peso_neto && unidad_peso_bruto == o.unidad_peso_bruto && unidad_peso_neto == o.unidad_peso_neto && cantidad_bulto == o.cantidad_bulto && unidad_bulto == o.unidad_bulto && volumen_bulto == o.volumen_bulto && unidad_volumen == o.unidad_volumen end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 252 def hash [, , numero_contenedor, numero_referencia, peso_bruto, peso_neto, unidad_peso_bruto, unidad_peso_neto, cantidad_bulto, unidad_bulto, volumen_bulto, unidad_volumen].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[0-9]{1,20}$/) if !@numero_referencia.nil? && @numero_referencia !~ pattern invalid_properties.push("invalid value for \"numero_referencia\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 |
# File 'lib/ecf_dgii/generated/models/ecf44_informaciones_adicionales.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@numero_referencia.nil? && @numero_referencia !~ Regexp.new(/^[0-9]{1,20}$/) true end |