Class: EcfDgii::Generated::Ecf44Pagina

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf44_pagina.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf44Pagina

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf44Pagina` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf44Pagina`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pagina_no')
    self.pagina_no = attributes[:'pagina_no']
  end

  if attributes.key?(:'no_linea_desde')
    self.no_linea_desde = attributes[:'no_linea_desde']
  end

  if attributes.key?(:'no_linea_hasta')
    self.no_linea_hasta = attributes[:'no_linea_hasta']
  end

  if attributes.key?(:'subtotal_exento_pagina')
    self.subtotal_exento_pagina = attributes[:'subtotal_exento_pagina']
  end

  if attributes.key?(:'subtotal_impuesto_adicional_pagina')
    self.subtotal_impuesto_adicional_pagina = attributes[:'subtotal_impuesto_adicional_pagina']
  end

  if attributes.key?(:'subtotal_impuesto_adicional')
    self.subtotal_impuesto_adicional = attributes[:'subtotal_impuesto_adicional']
  end

  if attributes.key?(:'monto_subtotal_pagina')
    self.monto_subtotal_pagina = attributes[:'monto_subtotal_pagina']
  end

  if attributes.key?(:'subtotal_monto_no_facturable_pagina')
    self.subtotal_monto_no_facturable_pagina = attributes[:'subtotal_monto_no_facturable_pagina']
  end
end

Instance Attribute Details

#monto_subtotal_paginaObject

Returns the value of attribute monto_subtotal_pagina.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 30

def monto_subtotal_pagina
  @monto_subtotal_pagina
end

#no_linea_desdeObject

Returns the value of attribute no_linea_desde.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 20

def no_linea_desde
  @no_linea_desde
end

#no_linea_hastaObject

Returns the value of attribute no_linea_hasta.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 22

def no_linea_hasta
  @no_linea_hasta
end

#pagina_noObject

Returns the value of attribute pagina_no.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 18

def pagina_no
  @pagina_no
end

#subtotal_exento_paginaObject

Returns the value of attribute subtotal_exento_pagina.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 24

def subtotal_exento_pagina
  @subtotal_exento_pagina
end

#subtotal_impuesto_adicionalObject

Returns the value of attribute subtotal_impuesto_adicional.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 28

def subtotal_impuesto_adicional
  @subtotal_impuesto_adicional
end

#subtotal_impuesto_adicional_paginaObject

Returns the value of attribute subtotal_impuesto_adicional_pagina.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 26

def subtotal_impuesto_adicional_pagina
  @subtotal_impuesto_adicional_pagina
end

#subtotal_monto_no_facturable_paginaObject

Returns the value of attribute subtotal_monto_no_facturable_pagina.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 32

def subtotal_monto_no_facturable_pagina
  @subtotal_monto_no_facturable_pagina
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 35

def self.attribute_map
  {
    :'pagina_no' => :'paginaNo',
    :'no_linea_desde' => :'noLineaDesde',
    :'no_linea_hasta' => :'noLineaHasta',
    :'subtotal_exento_pagina' => :'subtotalExentoPagina',
    :'subtotal_impuesto_adicional_pagina' => :'subtotalImpuestoAdicionalPagina',
    :'subtotal_impuesto_adicional' => :'subtotalImpuestoAdicional',
    :'monto_subtotal_pagina' => :'montoSubtotalPagina',
    :'subtotal_monto_no_facturable_pagina' => :'subtotalMontoNoFacturablePagina'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 180

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 73

def self.openapi_nullable
  Set.new([
    :'pagina_no',
    :'no_linea_desde',
    :'no_linea_hasta',
    :'subtotal_exento_pagina',
    :'subtotal_impuesto_adicional_pagina',
    :'subtotal_impuesto_adicional',
    :'monto_subtotal_pagina',
    :'subtotal_monto_no_facturable_pagina'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 59

def self.openapi_types
  {
    :'pagina_no' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'no_linea_desde' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'no_linea_hasta' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'subtotal_exento_pagina' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'subtotal_impuesto_adicional_pagina' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico',
    :'subtotal_impuesto_adicional' => :'Ecf44SubtotalImpuestoAdicional',
    :'monto_subtotal_pagina' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'subtotal_monto_no_facturable_pagina' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pagina_no == o.pagina_no &&
      no_linea_desde == o.no_linea_desde &&
      no_linea_hasta == o.no_linea_hasta &&
      subtotal_exento_pagina == o.subtotal_exento_pagina &&
      subtotal_impuesto_adicional_pagina == o.subtotal_impuesto_adicional_pagina &&
      subtotal_impuesto_adicional == o.subtotal_impuesto_adicional &&
      monto_subtotal_pagina == o.monto_subtotal_pagina &&
      subtotal_monto_no_facturable_pagina == o.subtotal_monto_no_facturable_pagina
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 167

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



173
174
175
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 173

def hash
  [pagina_no, no_linea_desde, no_linea_hasta, subtotal_exento_pagina, subtotal_impuesto_adicional_pagina, subtotal_impuesto_adicional, monto_subtotal_pagina, subtotal_monto_no_facturable_pagina].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 202

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
# File 'lib/ecf_dgii/generated/models/ecf44_pagina.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end