Class: EcfDgii::Generated::Ecf45DescuentoORecargo

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf45DescuentoORecargo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf45DescuentoORecargo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf45DescuentoORecargo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'numero_linea')
    self.numero_linea = attributes[:'numero_linea']
  else
    self.numero_linea = nil
  end

  if attributes.key?(:'tipo_ajuste')
    self.tipo_ajuste = attributes[:'tipo_ajuste']
  else
    self.tipo_ajuste = nil
  end

  if attributes.key?(:'indicador_norma1007')
    self.indicador_norma1007 = attributes[:'indicador_norma1007']
  end

  if attributes.key?(:'descripcion_descuentoo_recargo')
    self.descripcion_descuentoo_recargo = attributes[:'descripcion_descuentoo_recargo']
  end

  if attributes.key?(:'tipo_valor')
    self.tipo_valor = attributes[:'tipo_valor']
  end

  if attributes.key?(:'valor_descuentoo_recargo')
    self.valor_descuentoo_recargo = attributes[:'valor_descuentoo_recargo']
  end

  if attributes.key?(:'monto_descuentoo_recargo')
    self.monto_descuentoo_recargo = attributes[:'monto_descuentoo_recargo']
  end

  if attributes.key?(:'monto_descuentoo_recargo_otra_moneda')
    self.monto_descuentoo_recargo_otra_moneda = attributes[:'monto_descuentoo_recargo_otra_moneda']
  end

  if attributes.key?(:'indicador_facturacion_descuentoo_recargo')
    self.indicador_facturacion_descuentoo_recargo = attributes[:'indicador_facturacion_descuentoo_recargo']
  end
end

Instance Attribute Details

#descripcion_descuentoo_recargoObject

Returns the value of attribute descripcion_descuentoo_recargo.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 24

def descripcion_descuentoo_recargo
  @descripcion_descuentoo_recargo
end

#indicador_facturacion_descuentoo_recargoObject

Returns the value of attribute indicador_facturacion_descuentoo_recargo.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 34

def indicador_facturacion_descuentoo_recargo
  @indicador_facturacion_descuentoo_recargo
end

#indicador_norma1007Object

Returns the value of attribute indicador_norma1007.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 22

def indicador_norma1007
  @indicador_norma1007
end

#monto_descuentoo_recargoObject

Returns the value of attribute monto_descuentoo_recargo.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 30

def monto_descuentoo_recargo
  @monto_descuentoo_recargo
end

#monto_descuentoo_recargo_otra_monedaObject

Returns the value of attribute monto_descuentoo_recargo_otra_moneda.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 32

def monto_descuentoo_recargo_otra_moneda
  @monto_descuentoo_recargo_otra_moneda
end

#numero_lineaObject

Returns the value of attribute numero_linea.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 18

def numero_linea
  @numero_linea
end

#tipo_ajusteObject

Returns the value of attribute tipo_ajuste.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 20

def tipo_ajuste
  @tipo_ajuste
end

#tipo_valorObject

Returns the value of attribute tipo_valor.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 26

def tipo_valor
  @tipo_valor
end

#valor_descuentoo_recargoObject

Returns the value of attribute valor_descuentoo_recargo.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 28

def valor_descuentoo_recargo
  @valor_descuentoo_recargo
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 59

def self.attribute_map
  {
    :'numero_linea' => :'numeroLinea',
    :'tipo_ajuste' => :'tipoAjuste',
    :'indicador_norma1007' => :'indicadorNorma1007',
    :'descripcion_descuentoo_recargo' => :'descripcionDescuentooRecargo',
    :'tipo_valor' => :'tipoValor',
    :'valor_descuentoo_recargo' => :'valorDescuentooRecargo',
    :'monto_descuentoo_recargo' => :'montoDescuentooRecargo',
    :'monto_descuentoo_recargo_otra_moneda' => :'montoDescuentooRecargoOtraMoneda',
    :'indicador_facturacion_descuentoo_recargo' => :'indicadorFacturacionDescuentooRecargo'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
103
104
105
106
107
108
109
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 99

def self.openapi_nullable
  Set.new([
    :'indicador_norma1007',
    :'descripcion_descuentoo_recargo',
    :'tipo_valor',
    :'valor_descuentoo_recargo',
    :'monto_descuentoo_recargo',
    :'monto_descuentoo_recargo_otra_moneda',
    :'indicador_facturacion_descuentoo_recargo'
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 84

def self.openapi_types
  {
    :'numero_linea' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner',
    :'tipo_ajuste' => :'Ecf45TipoAjusteType',
    :'indicador_norma1007' => :'IndicadorNorma1007Type',
    :'descripcion_descuentoo_recargo' => :'String',
    :'tipo_valor' => :'TipoDescuentoRecargoType',
    :'valor_descuentoo_recargo' => :'Ecf31DescuentoORecargoValorDescuentooRecargo',
    :'monto_descuentoo_recargo' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_descuentoo_recargo_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'indicador_facturacion_descuentoo_recargo' => :'IndicadorFacturacionDRType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      numero_linea == o.numero_linea &&
      tipo_ajuste == o.tipo_ajuste &&
      indicador_norma1007 == o.indicador_norma1007 &&
      descripcion_descuentoo_recargo == o.descripcion_descuentoo_recargo &&
      tipo_valor == o.tipo_valor &&
      valor_descuentoo_recargo == o.valor_descuentoo_recargo &&
      monto_descuentoo_recargo == o.monto_descuentoo_recargo &&
      monto_descuentoo_recargo_otra_moneda == o.monto_descuentoo_recargo_otra_moneda &&
      indicador_facturacion_descuentoo_recargo == o.indicador_facturacion_descuentoo_recargo
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 237

def hash
  [numero_linea, tipo_ajuste, indicador_norma1007, descripcion_descuentoo_recargo, tipo_valor, valor_descuentoo_recargo, monto_descuentoo_recargo, monto_descuentoo_recargo_otra_moneda, indicador_facturacion_descuentoo_recargo].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @numero_linea.nil?
    invalid_properties.push('invalid value for "numero_linea", numero_linea cannot be nil.')
  end

  if @tipo_ajuste.nil?
    invalid_properties.push('invalid value for "tipo_ajuste", tipo_ajuste cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
190
191
# File 'lib/ecf_dgii/generated/models/ecf45_descuento_o_recargo.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @numero_linea.nil?
  return false if @tipo_ajuste.nil?
  true
end