Class: EcfDgii::Generated::Ecf45OtraMoneda
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf45OtraMoneda
- Defined in:
- lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#impuestos_adicionales_otra_moneda ⇒ Object
Returns the value of attribute impuestos_adicionales_otra_moneda.
-
#monto_exento_otra_moneda ⇒ Object
Returns the value of attribute monto_exento_otra_moneda.
-
#monto_gravado1_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado1_otra_moneda.
-
#monto_gravado2_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado2_otra_moneda.
-
#monto_gravado3_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado3_otra_moneda.
-
#monto_gravado_total_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado_total_otra_moneda.
-
#monto_impuesto_adicional_otra_moneda ⇒ Object
Returns the value of attribute monto_impuesto_adicional_otra_moneda.
-
#monto_total_otra_moneda ⇒ Object
Returns the value of attribute monto_total_otra_moneda.
-
#tipo_cambio ⇒ Object
Returns the value of attribute tipo_cambio.
-
#tipo_moneda ⇒ Object
Returns the value of attribute tipo_moneda.
-
#total_itbis1_otra_moneda ⇒ Object
Returns the value of attribute total_itbis1_otra_moneda.
-
#total_itbis2_otra_moneda ⇒ Object
Returns the value of attribute total_itbis2_otra_moneda.
-
#total_itbis3_otra_moneda ⇒ Object
Returns the value of attribute total_itbis3_otra_moneda.
-
#total_itbis_otra_moneda ⇒ Object
Returns the value of attribute total_itbis_otra_moneda.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf45OtraMoneda
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf45OtraMoneda
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 140 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf45OtraMoneda` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf45OtraMoneda`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tipo_moneda') self.tipo_moneda = attributes[:'tipo_moneda'] end if attributes.key?(:'tipo_cambio') self.tipo_cambio = attributes[:'tipo_cambio'] end if attributes.key?(:'monto_gravado_total_otra_moneda') self.monto_gravado_total_otra_moneda = attributes[:'monto_gravado_total_otra_moneda'] end if attributes.key?(:'monto_gravado1_otra_moneda') self.monto_gravado1_otra_moneda = attributes[:'monto_gravado1_otra_moneda'] end if attributes.key?(:'monto_gravado2_otra_moneda') self.monto_gravado2_otra_moneda = attributes[:'monto_gravado2_otra_moneda'] end if attributes.key?(:'monto_gravado3_otra_moneda') self.monto_gravado3_otra_moneda = attributes[:'monto_gravado3_otra_moneda'] end if attributes.key?(:'monto_exento_otra_moneda') self.monto_exento_otra_moneda = attributes[:'monto_exento_otra_moneda'] end if attributes.key?(:'total_itbis_otra_moneda') self.total_itbis_otra_moneda = attributes[:'total_itbis_otra_moneda'] end if attributes.key?(:'total_itbis1_otra_moneda') self.total_itbis1_otra_moneda = attributes[:'total_itbis1_otra_moneda'] end if attributes.key?(:'total_itbis2_otra_moneda') self.total_itbis2_otra_moneda = attributes[:'total_itbis2_otra_moneda'] end if attributes.key?(:'total_itbis3_otra_moneda') self.total_itbis3_otra_moneda = attributes[:'total_itbis3_otra_moneda'] end if attributes.key?(:'monto_impuesto_adicional_otra_moneda') self.monto_impuesto_adicional_otra_moneda = attributes[:'monto_impuesto_adicional_otra_moneda'] end if attributes.key?(:'impuestos_adicionales_otra_moneda') if (value = attributes[:'impuestos_adicionales_otra_moneda']).is_a?(Array) self.impuestos_adicionales_otra_moneda = value end end if attributes.key?(:'monto_total_otra_moneda') self.monto_total_otra_moneda = attributes[:'monto_total_otra_moneda'] end end |
Instance Attribute Details
#impuestos_adicionales_otra_moneda ⇒ Object
Returns the value of attribute impuestos_adicionales_otra_moneda.
42 43 44 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 42 def impuestos_adicionales_otra_moneda @impuestos_adicionales_otra_moneda end |
#monto_exento_otra_moneda ⇒ Object
Returns the value of attribute monto_exento_otra_moneda.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 30 def monto_exento_otra_moneda @monto_exento_otra_moneda end |
#monto_gravado1_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado1_otra_moneda.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 24 def monto_gravado1_otra_moneda @monto_gravado1_otra_moneda end |
#monto_gravado2_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado2_otra_moneda.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 26 def monto_gravado2_otra_moneda @monto_gravado2_otra_moneda end |
#monto_gravado3_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado3_otra_moneda.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 28 def monto_gravado3_otra_moneda @monto_gravado3_otra_moneda end |
#monto_gravado_total_otra_moneda ⇒ Object
Returns the value of attribute monto_gravado_total_otra_moneda.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 22 def monto_gravado_total_otra_moneda @monto_gravado_total_otra_moneda end |
#monto_impuesto_adicional_otra_moneda ⇒ Object
Returns the value of attribute monto_impuesto_adicional_otra_moneda.
40 41 42 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 40 def monto_impuesto_adicional_otra_moneda @monto_impuesto_adicional_otra_moneda end |
#monto_total_otra_moneda ⇒ Object
Returns the value of attribute monto_total_otra_moneda.
44 45 46 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 44 def monto_total_otra_moneda @monto_total_otra_moneda end |
#tipo_cambio ⇒ Object
Returns the value of attribute tipo_cambio.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 20 def tipo_cambio @tipo_cambio end |
#tipo_moneda ⇒ Object
Returns the value of attribute tipo_moneda.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 18 def tipo_moneda @tipo_moneda end |
#total_itbis1_otra_moneda ⇒ Object
Returns the value of attribute total_itbis1_otra_moneda.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 34 def total_itbis1_otra_moneda @total_itbis1_otra_moneda end |
#total_itbis2_otra_moneda ⇒ Object
Returns the value of attribute total_itbis2_otra_moneda.
36 37 38 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 36 def total_itbis2_otra_moneda @total_itbis2_otra_moneda end |
#total_itbis3_otra_moneda ⇒ Object
Returns the value of attribute total_itbis3_otra_moneda.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 38 def total_itbis3_otra_moneda @total_itbis3_otra_moneda end |
#total_itbis_otra_moneda ⇒ Object
Returns the value of attribute total_itbis_otra_moneda.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 32 def total_itbis_otra_moneda @total_itbis_otra_moneda end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 69 def self.attribute_map { :'tipo_moneda' => :'tipoMoneda', :'tipo_cambio' => :'tipoCambio', :'monto_gravado_total_otra_moneda' => :'montoGravadoTotalOtraMoneda', :'monto_gravado1_otra_moneda' => :'montoGravado1OtraMoneda', :'monto_gravado2_otra_moneda' => :'montoGravado2OtraMoneda', :'monto_gravado3_otra_moneda' => :'montoGravado3OtraMoneda', :'monto_exento_otra_moneda' => :'montoExentoOtraMoneda', :'total_itbis_otra_moneda' => :'totalITBISOtraMoneda', :'total_itbis1_otra_moneda' => :'totalITBIS1OtraMoneda', :'total_itbis2_otra_moneda' => :'totalITBIS2OtraMoneda', :'total_itbis3_otra_moneda' => :'totalITBIS3OtraMoneda', :'monto_impuesto_adicional_otra_moneda' => :'montoImpuestoAdicionalOtraMoneda', :'impuestos_adicionales_otra_moneda' => :'impuestosAdicionalesOtraMoneda', :'monto_total_otra_moneda' => :'montoTotalOtraMoneda' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 264 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 119 def self.openapi_nullable Set.new([ :'tipo_moneda', :'tipo_cambio', :'monto_gravado_total_otra_moneda', :'monto_gravado1_otra_moneda', :'monto_gravado2_otra_moneda', :'monto_gravado3_otra_moneda', :'monto_exento_otra_moneda', :'total_itbis_otra_moneda', :'total_itbis1_otra_moneda', :'total_itbis2_otra_moneda', :'total_itbis3_otra_moneda', :'monto_impuesto_adicional_otra_moneda', :'impuestos_adicionales_otra_moneda', :'monto_total_otra_moneda' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 99 def self.openapi_types { :'tipo_moneda' => :'TipoMonedaType', :'tipo_cambio' => :'Ecf31OtraMonedaTipoCambio', :'monto_gravado_total_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_gravado1_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_gravado2_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_gravado3_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_exento_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis1_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis2_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'total_itbis3_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo', :'monto_impuesto_adicional_otra_moneda' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico', :'impuestos_adicionales_otra_moneda' => :'Array<Ecf45ImpuestoAdicionalOtraMoneda>', :'monto_total_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 230 def ==(o) return true if self.equal?(o) self.class == o.class && tipo_moneda == o.tipo_moneda && tipo_cambio == o.tipo_cambio && monto_gravado_total_otra_moneda == o.monto_gravado_total_otra_moneda && monto_gravado1_otra_moneda == o.monto_gravado1_otra_moneda && monto_gravado2_otra_moneda == o.monto_gravado2_otra_moneda && monto_gravado3_otra_moneda == o.monto_gravado3_otra_moneda && monto_exento_otra_moneda == o.monto_exento_otra_moneda && total_itbis_otra_moneda == o.total_itbis_otra_moneda && total_itbis1_otra_moneda == o.total_itbis1_otra_moneda && total_itbis2_otra_moneda == o.total_itbis2_otra_moneda && total_itbis3_otra_moneda == o.total_itbis3_otra_moneda && monto_impuesto_adicional_otra_moneda == o.monto_impuesto_adicional_otra_moneda && impuestos_adicionales_otra_moneda == o.impuestos_adicionales_otra_moneda && monto_total_otra_moneda == o.monto_total_otra_moneda end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 257 def hash [tipo_moneda, tipo_cambio, monto_gravado_total_otra_moneda, monto_gravado1_otra_moneda, monto_gravado2_otra_moneda, monto_gravado3_otra_moneda, monto_exento_otra_moneda, total_itbis_otra_moneda, total_itbis1_otra_moneda, total_itbis2_otra_moneda, total_itbis3_otra_moneda, monto_impuesto_adicional_otra_moneda, impuestos_adicionales_otra_moneda, monto_total_otra_moneda].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
215 216 217 218 219 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 215 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 |
# File 'lib/ecf_dgii/generated/models/ecf45_otra_moneda.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |