Class: EcfDgii::Generated::Ecf46InformacionesAdicionales

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf46InformacionesAdicionales

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 180

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf46InformacionesAdicionales` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf46InformacionesAdicionales`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'fecha_embarque')
    self.fecha_embarque = attributes[:'fecha_embarque']
  end

  if attributes.key?(:'numero_embarque')
    self.numero_embarque = attributes[:'numero_embarque']
  end

  if attributes.key?(:'numero_contenedor')
    self.numero_contenedor = attributes[:'numero_contenedor']
  end

  if attributes.key?(:'numero_referencia')
    self.numero_referencia = attributes[:'numero_referencia']
  end

  if attributes.key?(:'nombre_puerto_embarque')
    self.nombre_puerto_embarque = attributes[:'nombre_puerto_embarque']
  end

  if attributes.key?(:'condiciones_entrega')
    self.condiciones_entrega = attributes[:'condiciones_entrega']
  end

  if attributes.key?(:'total_fob')
    self.total_fob = attributes[:'total_fob']
  end

  if attributes.key?(:'seguro')
    self.seguro = attributes[:'seguro']
  end

  if attributes.key?(:'flete')
    self.flete = attributes[:'flete']
  end

  if attributes.key?(:'otros_gastos')
    self.otros_gastos = attributes[:'otros_gastos']
  end

  if attributes.key?(:'total_cif')
    self.total_cif = attributes[:'total_cif']
  end

  if attributes.key?(:'regimen_aduanero')
    self.regimen_aduanero = attributes[:'regimen_aduanero']
  end

  if attributes.key?(:'nombre_puerto_salida')
    self.nombre_puerto_salida = attributes[:'nombre_puerto_salida']
  end

  if attributes.key?(:'nombre_puerto_desembarque')
    self.nombre_puerto_desembarque = attributes[:'nombre_puerto_desembarque']
  end

  if attributes.key?(:'peso_bruto')
    self.peso_bruto = attributes[:'peso_bruto']
  end

  if attributes.key?(:'peso_neto')
    self.peso_neto = attributes[:'peso_neto']
  end

  if attributes.key?(:'unidad_peso_bruto')
    self.unidad_peso_bruto = attributes[:'unidad_peso_bruto']
  end

  if attributes.key?(:'unidad_peso_neto')
    self.unidad_peso_neto = attributes[:'unidad_peso_neto']
  end

  if attributes.key?(:'cantidad_bulto')
    self.cantidad_bulto = attributes[:'cantidad_bulto']
  end

  if attributes.key?(:'unidad_bulto')
    self.unidad_bulto = attributes[:'unidad_bulto']
  end

  if attributes.key?(:'volumen_bulto')
    self.volumen_bulto = attributes[:'volumen_bulto']
  end

  if attributes.key?(:'unidad_volumen')
    self.unidad_volumen = attributes[:'unidad_volumen']
  end
end

Instance Attribute Details

#cantidad_bultoObject

Returns the value of attribute cantidad_bulto.



54
55
56
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 54

def cantidad_bulto
  @cantidad_bulto
end

#condiciones_entregaObject

Returns the value of attribute condiciones_entrega.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 28

def condiciones_entrega
  @condiciones_entrega
end

#fecha_embarqueObject

Returns the value of attribute fecha_embarque.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 18

def fecha_embarque
  @fecha_embarque
end

#fleteObject

Returns the value of attribute flete.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 34

def flete
  @flete
end

#nombre_puerto_desembarqueObject

Returns the value of attribute nombre_puerto_desembarque.



44
45
46
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 44

def nombre_puerto_desembarque
  @nombre_puerto_desembarque
end

#nombre_puerto_embarqueObject

Returns the value of attribute nombre_puerto_embarque.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 26

def nombre_puerto_embarque
  @nombre_puerto_embarque
end

#nombre_puerto_salidaObject

Returns the value of attribute nombre_puerto_salida.



42
43
44
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 42

def nombre_puerto_salida
  @nombre_puerto_salida
end

#numero_contenedorObject

Returns the value of attribute numero_contenedor.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 22

def numero_contenedor
  @numero_contenedor
end

#numero_embarqueObject

Returns the value of attribute numero_embarque.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 20

def numero_embarque
  @numero_embarque
end

#numero_referenciaObject

Returns the value of attribute numero_referencia.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 24

def numero_referencia
  @numero_referencia
end

#otros_gastosObject

Returns the value of attribute otros_gastos.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 36

def otros_gastos
  @otros_gastos
end

#peso_brutoObject

Returns the value of attribute peso_bruto.



46
47
48
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 46

def peso_bruto
  @peso_bruto
end

#peso_netoObject

Returns the value of attribute peso_neto.



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 48

def peso_neto
  @peso_neto
end

#regimen_aduaneroObject

Returns the value of attribute regimen_aduanero.



40
41
42
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 40

def regimen_aduanero
  @regimen_aduanero
end

#seguroObject

Returns the value of attribute seguro.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 32

def seguro
  @seguro
end

#total_cifObject

Returns the value of attribute total_cif.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 38

def total_cif
  @total_cif
end

#total_fobObject

Returns the value of attribute total_fob.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 30

def total_fob
  @total_fob
end

#unidad_bultoObject

Returns the value of attribute unidad_bulto.



56
57
58
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 56

def unidad_bulto
  @unidad_bulto
end

#unidad_peso_brutoObject

Returns the value of attribute unidad_peso_bruto.



50
51
52
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 50

def unidad_peso_bruto
  @unidad_peso_bruto
end

#unidad_peso_netoObject

Returns the value of attribute unidad_peso_neto.



52
53
54
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 52

def unidad_peso_neto
  @unidad_peso_neto
end

#unidad_volumenObject

Returns the value of attribute unidad_volumen.



60
61
62
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 60

def unidad_volumen
  @unidad_volumen
end

#volumen_bultoObject

Returns the value of attribute volumen_bulto.



58
59
60
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 58

def volumen_bulto
  @volumen_bulto
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



113
114
115
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 113

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



118
119
120
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 118

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 85

def self.attribute_map
  {
    :'fecha_embarque' => :'fechaEmbarque',
    :'numero_embarque' => :'numeroEmbarque',
    :'numero_contenedor' => :'numeroContenedor',
    :'numero_referencia' => :'numeroReferencia',
    :'nombre_puerto_embarque' => :'nombrePuertoEmbarque',
    :'condiciones_entrega' => :'condicionesEntrega',
    :'total_fob' => :'totalFob',
    :'seguro' => :'seguro',
    :'flete' => :'flete',
    :'otros_gastos' => :'otrosGastos',
    :'total_cif' => :'totalCif',
    :'regimen_aduanero' => :'regimenAduanero',
    :'nombre_puerto_salida' => :'nombrePuertoSalida',
    :'nombre_puerto_desembarque' => :'nombrePuertoDesembarque',
    :'peso_bruto' => :'pesoBruto',
    :'peso_neto' => :'pesoNeto',
    :'unidad_peso_bruto' => :'unidadPesoBruto',
    :'unidad_peso_neto' => :'unidadPesoNeto',
    :'cantidad_bulto' => :'cantidadBulto',
    :'unidad_bulto' => :'unidadBulto',
    :'volumen_bulto' => :'volumenBulto',
    :'unidad_volumen' => :'unidadVolumen'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 359

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 151

def self.openapi_nullable
  Set.new([
    :'fecha_embarque',
    :'numero_embarque',
    :'numero_contenedor',
    :'numero_referencia',
    :'nombre_puerto_embarque',
    :'condiciones_entrega',
    :'total_fob',
    :'seguro',
    :'flete',
    :'otros_gastos',
    :'total_cif',
    :'regimen_aduanero',
    :'nombre_puerto_salida',
    :'nombre_puerto_desembarque',
    :'peso_bruto',
    :'peso_neto',
    :'unidad_peso_bruto',
    :'unidad_peso_neto',
    :'cantidad_bulto',
    :'unidad_bulto',
    :'volumen_bulto',
    :'unidad_volumen'
  ])
end

.openapi_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 123

def self.openapi_types
  {
    :'fecha_embarque' => :'Time',
    :'numero_embarque' => :'String',
    :'numero_contenedor' => :'String',
    :'numero_referencia' => :'String',
    :'nombre_puerto_embarque' => :'String',
    :'condiciones_entrega' => :'String',
    :'total_fob' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico',
    :'seguro' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico',
    :'flete' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico',
    :'otros_gastos' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico',
    :'total_cif' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'regimen_aduanero' => :'String',
    :'nombre_puerto_salida' => :'String',
    :'nombre_puerto_desembarque' => :'String',
    :'peso_bruto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'peso_neto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'unidad_peso_bruto' => :'UnidadMedidaType',
    :'unidad_peso_neto' => :'UnidadMedidaType',
    :'cantidad_bulto' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'unidad_bulto' => :'UnidadMedidaType',
    :'volumen_bulto' => :'Ecf31ImpuestoAdicional2MontoImpuestoSelectivoConsumoEspecifico',
    :'unidad_volumen' => :'UnidadMedidaType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 317

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      fecha_embarque == o.fecha_embarque &&
      numero_embarque == o.numero_embarque &&
      numero_contenedor == o.numero_contenedor &&
      numero_referencia == o.numero_referencia &&
      nombre_puerto_embarque == o.nombre_puerto_embarque &&
      condiciones_entrega == o.condiciones_entrega &&
      total_fob == o.total_fob &&
      seguro == o.seguro &&
      flete == o.flete &&
      otros_gastos == o.otros_gastos &&
      total_cif == o.total_cif &&
      regimen_aduanero == o.regimen_aduanero &&
      nombre_puerto_salida == o.nombre_puerto_salida &&
      nombre_puerto_desembarque == o.nombre_puerto_desembarque &&
      peso_bruto == o.peso_bruto &&
      peso_neto == o.peso_neto &&
      unidad_peso_bruto == o.unidad_peso_bruto &&
      unidad_peso_neto == o.unidad_peso_neto &&
      cantidad_bulto == o.cantidad_bulto &&
      unidad_bulto == o.unidad_bulto &&
      volumen_bulto == o.volumen_bulto &&
      unidad_volumen == o.unidad_volumen
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


346
347
348
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 346

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



352
353
354
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 352

def hash
  [fecha_embarque, numero_embarque, numero_contenedor, numero_referencia, nombre_puerto_embarque, condiciones_entrega, total_fob, seguro, flete, otros_gastos, total_cif, regimen_aduanero, nombre_puerto_salida, nombre_puerto_desembarque, peso_bruto, peso_neto, unidad_peso_bruto, unidad_peso_neto, cantidad_bulto, unidad_bulto, volumen_bulto, unidad_volumen].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



285
286
287
288
289
290
291
292
293
294
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 285

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[0-9]{1,20}$/)
  if !@numero_referencia.nil? && @numero_referencia !~ pattern
    invalid_properties.push("invalid value for \"numero_referencia\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 381

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



298
299
300
301
302
# File 'lib/ecf_dgii/generated/models/ecf46_informaciones_adicionales.rb', line 298

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@numero_referencia.nil? && @numero_referencia !~ Regexp.new(/^[0-9]{1,20}$/)
  true
end