Class: EcfDgii::Generated::Ecf46OtraMoneda

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf46OtraMoneda

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf46OtraMoneda` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf46OtraMoneda`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tipo_moneda')
    self.tipo_moneda = attributes[:'tipo_moneda']
  end

  if attributes.key?(:'tipo_cambio')
    self.tipo_cambio = attributes[:'tipo_cambio']
  end

  if attributes.key?(:'monto_gravado_total_otra_moneda')
    self.monto_gravado_total_otra_moneda = attributes[:'monto_gravado_total_otra_moneda']
  end

  if attributes.key?(:'monto_gravado3_otra_moneda')
    self.monto_gravado3_otra_moneda = attributes[:'monto_gravado3_otra_moneda']
  end

  if attributes.key?(:'total_itbis_otra_moneda')
    self.total_itbis_otra_moneda = attributes[:'total_itbis_otra_moneda']
  end

  if attributes.key?(:'total_itbis3_otra_moneda')
    self.total_itbis3_otra_moneda = attributes[:'total_itbis3_otra_moneda']
  end

  if attributes.key?(:'monto_total_otra_moneda')
    self.monto_total_otra_moneda = attributes[:'monto_total_otra_moneda']
  end
end

Instance Attribute Details

#monto_gravado3_otra_monedaObject

Returns the value of attribute monto_gravado3_otra_moneda.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 24

def monto_gravado3_otra_moneda
  @monto_gravado3_otra_moneda
end

#monto_gravado_total_otra_monedaObject

Returns the value of attribute monto_gravado_total_otra_moneda.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 22

def monto_gravado_total_otra_moneda
  @monto_gravado_total_otra_moneda
end

#monto_total_otra_monedaObject

Returns the value of attribute monto_total_otra_moneda.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 30

def monto_total_otra_moneda
  @monto_total_otra_moneda
end

#tipo_cambioObject

Returns the value of attribute tipo_cambio.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 20

def tipo_cambio
  @tipo_cambio
end

#tipo_monedaObject

Returns the value of attribute tipo_moneda.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 18

def tipo_moneda
  @tipo_moneda
end

#total_itbis3_otra_monedaObject

Returns the value of attribute total_itbis3_otra_moneda.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 28

def total_itbis3_otra_moneda
  @total_itbis3_otra_moneda
end

#total_itbis_otra_monedaObject

Returns the value of attribute total_itbis_otra_moneda.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 26

def total_itbis_otra_moneda
  @total_itbis_otra_moneda
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 55

def self.attribute_map
  {
    :'tipo_moneda' => :'tipoMoneda',
    :'tipo_cambio' => :'tipoCambio',
    :'monto_gravado_total_otra_moneda' => :'montoGravadoTotalOtraMoneda',
    :'monto_gravado3_otra_moneda' => :'montoGravado3OtraMoneda',
    :'total_itbis_otra_moneda' => :'totalITBISOtraMoneda',
    :'total_itbis3_otra_moneda' => :'totalITBIS3OtraMoneda',
    :'monto_total_otra_moneda' => :'montoTotalOtraMoneda'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
97
98
99
100
101
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 91

def self.openapi_nullable
  Set.new([
    :'tipo_moneda',
    :'tipo_cambio',
    :'monto_gravado_total_otra_moneda',
    :'monto_gravado3_otra_moneda',
    :'total_itbis_otra_moneda',
    :'total_itbis3_otra_moneda',
    :'monto_total_otra_moneda'
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 78

def self.openapi_types
  {
    :'tipo_moneda' => :'TipoMonedaType',
    :'tipo_cambio' => :'Ecf31OtraMonedaTipoCambio',
    :'monto_gravado_total_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_gravado3_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_itbis_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'total_itbis3_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_total_otra_moneda' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
174
175
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tipo_moneda == o.tipo_moneda &&
      tipo_cambio == o.tipo_cambio &&
      monto_gravado_total_otra_moneda == o.monto_gravado_total_otra_moneda &&
      monto_gravado3_otra_moneda == o.monto_gravado3_otra_moneda &&
      total_itbis_otra_moneda == o.total_itbis_otra_moneda &&
      total_itbis3_otra_moneda == o.total_itbis3_otra_moneda &&
      monto_total_otra_moneda == o.monto_total_otra_moneda
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 185

def hash
  [tipo_moneda, tipo_cambio, monto_gravado_total_otra_moneda, monto_gravado3_otra_moneda, total_itbis_otra_moneda, total_itbis3_otra_moneda, monto_total_otra_moneda].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
# File 'lib/ecf_dgii/generated/models/ecf46_otra_moneda.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end