Class: EcfDgii::Generated::Ecf47Subtotal

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf47_subtotal.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Ecf47Subtotal

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf47Subtotal` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf47Subtotal`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'numero_sub_total')
    self.numero_sub_total = attributes[:'numero_sub_total']
  end

  if attributes.key?(:'descripcion_subtotal')
    self.descripcion_subtotal = attributes[:'descripcion_subtotal']
  end

  if attributes.key?(:'orden')
    self.orden = attributes[:'orden']
  end

  if attributes.key?(:'sub_total_exento')
    self.sub_total_exento = attributes[:'sub_total_exento']
  end

  if attributes.key?(:'monto_sub_total')
    self.monto_sub_total = attributes[:'monto_sub_total']
  end

  if attributes.key?(:'lineas')
    self.lineas = attributes[:'lineas']
  end
end

Instance Attribute Details

#descripcion_subtotalObject

Returns the value of attribute descripcion_subtotal.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 20

def descripcion_subtotal
  @descripcion_subtotal
end

#lineasObject

Returns the value of attribute lineas.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 28

def lineas
  @lineas
end

#monto_sub_totalObject

Returns the value of attribute monto_sub_total.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 26

def monto_sub_total
  @monto_sub_total
end

#numero_sub_totalObject

Returns the value of attribute numero_sub_total.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 18

def numero_sub_total
  @numero_sub_total
end

#ordenObject

Returns the value of attribute orden.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 22

def orden
  @orden
end

#sub_total_exentoObject

Returns the value of attribute sub_total_exento.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 24

def sub_total_exento
  @sub_total_exento
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 31

def self.attribute_map
  {
    :'numero_sub_total' => :'numeroSubTotal',
    :'descripcion_subtotal' => :'descripcionSubtotal',
    :'orden' => :'orden',
    :'sub_total_exento' => :'subTotalExento',
    :'monto_sub_total' => :'montoSubTotal',
    :'lineas' => :'lineas'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
71
72
73
74
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 65

def self.openapi_nullable
  Set.new([
    :'numero_sub_total',
    :'descripcion_subtotal',
    :'orden',
    :'sub_total_exento',
    :'monto_sub_total',
    :'lineas'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 53

def self.openapi_types
  {
    :'numero_sub_total' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'descripcion_subtotal' => :'String',
    :'orden' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'sub_total_exento' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'monto_sub_total' => :'Ecf31DescuentoORecargoMontoDescuentooRecargo',
    :'lineas' => :'AcecfSummaryDtoReceptorHttpStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



134
135
136
137
138
139
140
141
142
143
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 134

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      numero_sub_total == o.numero_sub_total &&
      descripcion_subtotal == o.descripcion_subtotal &&
      orden == o.orden &&
      sub_total_exento == o.sub_total_exento &&
      monto_sub_total == o.monto_sub_total &&
      lineas == o.lineas
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 153

def hash
  [numero_sub_total, descripcion_subtotal, orden, sub_total_exento, monto_sub_total, lineas].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
# File 'lib/ecf_dgii/generated/models/ecf47_subtotal.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end