Class: EcfDgii::Generated::EcfReceptionRequestDto

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EcfReceptionRequestDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::EcfReceptionRequestDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::EcfReceptionRequestDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'message_id')
    self.message_id = attributes[:'message_id']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'company_rnc')
    self.company_rnc = attributes[:'company_rnc']
  end

  if attributes.key?(:'file_name')
    self.file_name = attributes[:'file_name']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  end

  if attributes.key?(:'updated_on')
    self.updated_on = attributes[:'updated_on']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'encf')
    self.encf = attributes[:'encf']
  end

  if attributes.key?(:'rnc_emisor')
    self.rnc_emisor = attributes[:'rnc_emisor']
  end

  if attributes.key?(:'tipo_ecf')
    self.tipo_ecf = attributes[:'tipo_ecf']
  end

  if attributes.key?(:'result_internal_file_name')
    self.result_internal_file_name = attributes[:'result_internal_file_name']
  end

  if attributes.key?(:'monto_total')
    self.monto_total = attributes[:'monto_total']
  end
end

Instance Attribute Details

#company_rncObject

Returns the value of attribute company_rnc.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 22

def company_rnc
  @company_rnc
end

#created_onObject

Returns the value of attribute created_on.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 28

def created_on
  @created_on
end

#encfObject

Returns the value of attribute encf.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 34

def encf
  @encf
end

#error_messageObject

Returns the value of attribute error_message.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 32

def error_message
  @error_message
end

#file_nameObject

Returns the value of attribute file_name.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 24

def file_name
  @file_name
end

#message_idObject

Returns the value of attribute message_id.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 18

def message_id
  @message_id
end

#monto_totalObject

Returns the value of attribute monto_total.



42
43
44
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 42

def monto_total
  @monto_total
end

#progressObject

Returns the value of attribute progress.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 26

def progress
  @progress
end

#result_internal_file_nameObject

Returns the value of attribute result_internal_file_name.



40
41
42
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 40

def result_internal_file_name
  @result_internal_file_name
end

#rnc_emisorObject

Returns the value of attribute rnc_emisor.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 36

def rnc_emisor
  @rnc_emisor
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 20

def tenant_id
  @tenant_id
end

#tipo_ecfObject

Returns the value of attribute tipo_ecf.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 38

def tipo_ecf
  @tipo_ecf
end

#updated_onObject

Returns the value of attribute updated_on.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 30

def updated_on
  @updated_on
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 67

def self.attribute_map
  {
    :'message_id' => :'messageId',
    :'tenant_id' => :'tenantId',
    :'company_rnc' => :'companyRnc',
    :'file_name' => :'fileName',
    :'progress' => :'progress',
    :'created_on' => :'createdOn',
    :'updated_on' => :'updatedOn',
    :'error_message' => :'errorMessage',
    :'encf' => :'encf',
    :'rnc_emisor' => :'rncEmisor',
    :'tipo_ecf' => :'tipoEcf',
    :'result_internal_file_name' => :'resultInternalFileName',
    :'monto_total' => :'montoTotal'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
119
120
121
122
123
124
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 115

def self.openapi_nullable
  Set.new([
    :'error_message',
    :'encf',
    :'rnc_emisor',
    :'tipo_ecf',
    :'result_internal_file_name',
    :'monto_total'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 96

def self.openapi_types
  {
    :'message_id' => :'String',
    :'tenant_id' => :'String',
    :'company_rnc' => :'String',
    :'file_name' => :'String',
    :'progress' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner',
    :'created_on' => :'Time',
    :'updated_on' => :'Time',
    :'error_message' => :'String',
    :'encf' => :'String',
    :'rnc_emisor' => :'String',
    :'tipo_ecf' => :'AllTipoECFTypes',
    :'result_internal_file_name' => :'String',
    :'monto_total' => :'EcfReceptionRequestDtoMontoTotal'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      message_id == o.message_id &&
      tenant_id == o.tenant_id &&
      company_rnc == o.company_rnc &&
      file_name == o.file_name &&
      progress == o.progress &&
      created_on == o.created_on &&
      updated_on == o.updated_on &&
      error_message == o.error_message &&
      encf == o.encf &&
      rnc_emisor == o.rnc_emisor &&
      tipo_ecf == o.tipo_ecf &&
      result_internal_file_name == o.result_internal_file_name &&
      monto_total == o.monto_total
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 238

def hash
  [message_id, tenant_id, company_rnc, file_name, progress, created_on, updated_on, error_message, encf, rnc_emisor, tipo_ecf, result_internal_file_name, monto_total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 197

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
# File 'lib/ecf_dgii/generated/models/ecf_reception_request_dto.rb', line 205

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end