Class: EcfDgii::Generated::EcfReceptorDto

Inherits:
ApiModelBase show all
Defined in:
lib/ecf_dgii/generated/models/ecf_receptor_dto.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EcfReceptorDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 152

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::EcfReceptorDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::EcfReceptorDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ecf_receptor_id')
    self.ecf_receptor_id = attributes[:'ecf_receptor_id']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'company_rnc')
    self.company_rnc = attributes[:'company_rnc']
  end

  if attributes.key?(:'encf')
    self.encf = attributes[:'encf']
  end

  if attributes.key?(:'rnc_emisor')
    self.rnc_emisor = attributes[:'rnc_emisor']
  end

  if attributes.key?(:'rnc_receptor')
    self.rnc_receptor = attributes[:'rnc_receptor']
  end

  if attributes.key?(:'tipo_ecf')
    self.tipo_ecf = attributes[:'tipo_ecf']
  end

  if attributes.key?(:'monto_total')
    self.monto_total = attributes[:'monto_total']
  end

  if attributes.key?(:'fecha_emision')
    self.fecha_emision = attributes[:'fecha_emision']
  end

  if attributes.key?(:'file_name')
    self.file_name = attributes[:'file_name']
  end

  if attributes.key?(:'raw_json_data')
    self.raw_json_data = attributes[:'raw_json_data']
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  end

  if attributes.key?(:'fecha_firma')
    self.fecha_firma = attributes[:'fecha_firma']
  end

  if attributes.key?(:'cod_sec')
    self.cod_sec = attributes[:'cod_sec']
  end

  if attributes.key?(:'estado')
    self.estado = attributes[:'estado']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  end

  if attributes.key?(:'ambiente')
    self.ambiente = attributes[:'ambiente']
  end

  if attributes.key?(:'url_impresion')
    self.url_impresion = attributes[:'url_impresion']
  end

  if attributes.key?(:'acecfs')
    if (value = attributes[:'acecfs']).is_a?(Array)
      self.acecfs = value
    end
  end
end

Instance Attribute Details

#acecfsObject

Returns the value of attribute acecfs.



56
57
58
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 56

def acecfs
  @acecfs
end

#ambienteObject

DGII environment serving this tenant ("Test"/"Certification"/"Production").



51
52
53
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 51

def ambiente
  @ambiente
end

#cod_secObject

Returns the value of attribute cod_sec.



44
45
46
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 44

def cod_sec
  @cod_sec
end

#company_rncObject

Returns the value of attribute company_rnc.



22
23
24
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 22

def company_rnc
  @company_rnc
end

#created_onObject

Returns the value of attribute created_on.



40
41
42
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 40

def created_on
  @created_on
end

#ecf_receptor_idObject

Returns the value of attribute ecf_receptor_id.



18
19
20
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 18

def ecf_receptor_id
  @ecf_receptor_id
end

#encfObject

Returns the value of attribute encf.



24
25
26
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 24

def encf
  @encf
end

#estadoObject

Returns the value of attribute estado.



46
47
48
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 46

def estado
  @estado
end

#fecha_emisionObject

Returns the value of attribute fecha_emision.



34
35
36
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 34

def fecha_emision
  @fecha_emision
end

#fecha_firmaObject

Returns the value of attribute fecha_firma.



42
43
44
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 42

def fecha_firma
  @fecha_firma
end

#file_nameObject

Returns the value of attribute file_name.



36
37
38
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 36

def file_name
  @file_name
end

#monto_totalObject

Returns the value of attribute monto_total.



32
33
34
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 32

def monto_total
  @monto_total
end

#progressObject

Returns the value of attribute progress.



48
49
50
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 48

def progress
  @progress
end

#raw_json_dataObject

Returns the value of attribute raw_json_data.



38
39
40
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 38

def raw_json_data
  @raw_json_data
end

#rnc_emisorObject

Returns the value of attribute rnc_emisor.



26
27
28
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 26

def rnc_emisor
  @rnc_emisor
end

#rnc_receptorObject

Returns the value of attribute rnc_receptor.



28
29
30
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 28

def rnc_receptor
  @rnc_receptor
end

#tenant_idObject

Returns the value of attribute tenant_id.



20
21
22
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 20

def tenant_id
  @tenant_id
end

#tipo_ecfObject

Returns the value of attribute tipo_ecf.



30
31
32
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 30

def tipo_ecf
  @tipo_ecf
end

#url_impresionObject

DGII consulta-timbre URL with QR query string.



54
55
56
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 54

def url_impresion
  @url_impresion
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



106
107
108
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 106

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



111
112
113
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 111

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 81

def self.attribute_map
  {
    :'ecf_receptor_id' => :'ecfReceptorId',
    :'tenant_id' => :'tenantId',
    :'company_rnc' => :'companyRnc',
    :'encf' => :'encf',
    :'rnc_emisor' => :'rncEmisor',
    :'rnc_receptor' => :'rncReceptor',
    :'tipo_ecf' => :'tipoEcf',
    :'monto_total' => :'montoTotal',
    :'fecha_emision' => :'fechaEmision',
    :'file_name' => :'fileName',
    :'raw_json_data' => :'rawJsonData',
    :'created_on' => :'createdOn',
    :'fecha_firma' => :'fechaFirma',
    :'cod_sec' => :'codSec',
    :'estado' => :'estado',
    :'progress' => :'progress',
    :'ambiente' => :'ambiente',
    :'url_impresion' => :'urlImpresion',
    :'acecfs' => :'acecfs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 301

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



141
142
143
144
145
146
147
148
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 141

def self.openapi_nullable
  Set.new([
    :'fecha_firma',
    :'cod_sec',
    :'estado',
    :'url_impresion',
  ])
end

.openapi_typesObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 116

def self.openapi_types
  {
    :'ecf_receptor_id' => :'String',
    :'tenant_id' => :'String',
    :'company_rnc' => :'String',
    :'encf' => :'String',
    :'rnc_emisor' => :'String',
    :'rnc_receptor' => :'String',
    :'tipo_ecf' => :'AllTipoECFTypes',
    :'monto_total' => :'SearchEcfsAmountFromParameter',
    :'fecha_emision' => :'Date',
    :'file_name' => :'String',
    :'raw_json_data' => :'String',
    :'created_on' => :'Time',
    :'fecha_firma' => :'Time',
    :'cod_sec' => :'String',
    :'estado' => :'AcecfSummaryDtoReceptorHttpStatus',
    :'progress' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner',
    :'ambiente' => :'String',
    :'url_impresion' => :'String',
    :'acecfs' => :'Array<AcecfSummaryDto>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ecf_receptor_id == o.ecf_receptor_id &&
      tenant_id == o.tenant_id &&
      company_rnc == o.company_rnc &&
      encf == o.encf &&
      rnc_emisor == o.rnc_emisor &&
      rnc_receptor == o.rnc_receptor &&
      tipo_ecf == o.tipo_ecf &&
      monto_total == o.monto_total &&
      fecha_emision == o.fecha_emision &&
      file_name == o.file_name &&
      raw_json_data == o.raw_json_data &&
      created_on == o.created_on &&
      fecha_firma == o.fecha_firma &&
      cod_sec == o.cod_sec &&
      estado == o.estado &&
      progress == o.progress &&
      ambiente == o.ambiente &&
      url_impresion == o.url_impresion &&
      acecfs == o.acecfs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 288

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



294
295
296
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 294

def hash
  [ecf_receptor_id, tenant_id, company_rnc, encf, rnc_emisor, rnc_receptor, tipo_ecf, monto_total, fecha_emision, file_name, raw_json_data, created_on, fecha_firma, cod_sec, estado, progress, ambiente, url_impresion, acecfs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



247
248
249
250
251
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 247

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
# File 'lib/ecf_dgii/generated/models/ecf_receptor_dto.rb', line 255

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end