Class: EcfDgii::Generated::RespuestaAnulacionRango

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb

Overview

Respuesta de anulación de rango de secuencias de e-NCF. Representa la respuesta del servicio de anulación de rangos de secuencias de comprobantes fiscales electrónicos. Este modelo se utiliza para procesar la respuesta del servicio web de anulación de e-NCF de la DGII. Servicio Web:• Endpoint: /api/operaciones/anularrango• Método: POST• Formato de entrada: XML (formato ANECF)• Formato de respuesta: JSON o XMLValidaciones del Servicio:• Tipo de archivo válido (XML)• Firma del documento válida• Tipo de comprobante válido• Secuencias no utilizadas previamente• RNC autorizado para realizar transaccionesReferencia Oficial:• Descripción Técnica de Facturación Electrónica v1.6, Sección "Anulación de e-NCF"• Formato Anulación de e-NCF v1.0 - DGII

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RespuestaAnulacionRango

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::RespuestaAnulacionRango` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::RespuestaAnulacionRango`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rnc')
    self.rnc = attributes[:'rnc']
  end

  if attributes.key?(:'codigo')
    self.codigo = attributes[:'codigo']
  end

  if attributes.key?(:'nombre')
    self.nombre = attributes[:'nombre']
  end

  if attributes.key?(:'mensajes')
    if (value = attributes[:'mensajes']).is_a?(Array)
      self.mensajes = value
    end
  end
end

Instance Attribute Details

#codigoObject

Código asociado al resultado de la validación de la anulación. Indica el código de estado del resultado de la operación de anulación. Los códigos proporcionan información sobre el éxito o fallo de la operación y los motivos específicos cuando hay errores.



23
24
25
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 23

def codigo
  @codigo
end

#mensajesObject

Mensajes asociados al resultado de la validación de la anulación. Array de mensajes que proporcionan información detallada sobre el resultado de la operación. Puede incluir mensajes de éxito, advertencias, o errores específicos que ocurrieron durante el proceso de validación y anulación de las secuencias.



29
30
31
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 29

def mensajes
  @mensajes
end

#nombreObject

Razón social del contribuyente que realizó la anulación. Nombre o razón social del contribuyente asociado al RNC que solicitó la anulación. Este campo proporciona información adicional para identificación del contribuyente y corresponde al nombre registrado en la DGII.



26
27
28
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 26

def nombre
  @nombre
end

#rncObject

Número de Registro Nacional del Contribuyente que envió la anulación. Corresponde al RNC del contribuyente que solicitó la anulación de las secuencias. Este valor debe coincidir con el RNC autorizado para realizar transacciones de anulación y debe estar registrado como Facturador Electrónico en la DGII.



20
21
22
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 20

def rnc
  @rnc
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 32

def self.attribute_map
  {
    :'rnc' => :'rnc',
    :'codigo' => :'codigo',
    :'nombre' => :'nombre',
    :'mensajes' => :'mensajes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 147

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
66
67
68
69
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 62

def self.openapi_nullable
  Set.new([
    :'rnc',
    :'codigo',
    :'nombre',
    :'mensajes'
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 52

def self.openapi_types
  {
    :'rnc' => :'String',
    :'codigo' => :'String',
    :'nombre' => :'String',
    :'mensajes' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



123
124
125
126
127
128
129
130
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 123

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rnc == o.rnc &&
      codigo == o.codigo &&
      nombre == o.nombre &&
      mensajes == o.mensajes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


134
135
136
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 134

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



140
141
142
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 140

def hash
  [rnc, codigo, nombre, mensajes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 169

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



116
117
118
119
# File 'lib/ecf_dgii/generated/models/respuesta_anulacion_rango.rb', line 116

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end