Class: EcfDgii::Generated::RespuestaConsultaEstado

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb

Overview

Representa la respuesta del servicio de consulta de estado de e-CF. Este modelo contiene la información de validez y estado de un comprobante fiscal electrónico consultado a través del servicio web de consulta estado de la DGII.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RespuestaConsultaEstado

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::RespuestaConsultaEstado` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::RespuestaConsultaEstado`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'codigo')
    self.codigo = attributes[:'codigo']
  end

  if attributes.key?(:'estado')
    self.estado = attributes[:'estado']
  end

  if attributes.key?(:'rnc_emisor')
    self.rnc_emisor = attributes[:'rnc_emisor']
  end

  if attributes.key?(:'ncf_electronico')
    self.ncf_electronico = attributes[:'ncf_electronico']
  end

  if attributes.key?(:'monto_total')
    self.monto_total = attributes[:'monto_total']
  end

  if attributes.key?(:'total_itbis')
    self.total_itbis = attributes[:'total_itbis']
  end

  if attributes.key?(:'fecha_emision')
    self.fecha_emision = attributes[:'fecha_emision']
  end

  if attributes.key?(:'fecha_firma')
    self.fecha_firma = attributes[:'fecha_firma']
  end

  if attributes.key?(:'rnc_comprador')
    self.rnc_comprador = attributes[:'rnc_comprador']
  end

  if attributes.key?(:'codigo_seguridad')
    self.codigo_seguridad = attributes[:'codigo_seguridad']
  end

  if attributes.key?(:'id_extranjero')
    self.id_extranjero = attributes[:'id_extranjero']
  end
end

Instance Attribute Details

#codigoObject

Returns the value of attribute codigo.



19
20
21
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 19

def codigo
  @codigo
end

#codigo_seguridadObject

Código de seguridad extraído de los primeros seis (6) dígitos del hash generado en el SignatureValue de la firma digital del e-CF recibido. Código de seguridad de 6 caracteres para validación del comprobante.



44
45
46
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 44

def codigo_seguridad
  @codigo_seguridad
end

#estadoObject

Estado de validación otorgado por Impuestos Internos al e-CF recibido. Descripción textual del estado del comprobante fiscal electrónico.



22
23
24
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 22

def estado
  @estado
end

#fecha_emisionObject

Fecha de emisión extraída del e-CF recibido. Fecha en que fue emitido el comprobante fiscal electrónico.



35
36
37
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 35

def fecha_emision
  @fecha_emision
end

#fecha_firmaObject

Fecha de firma extraída del e-CF recibido. Fecha en que fue firmado digitalmente el comprobante fiscal electrónico.



38
39
40
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 38

def fecha_firma
  @fecha_firma
end

#id_extranjeroObject

Identificación de extranjero extraída del e-CF recibido (si aplica). Número de identificación del comprador extranjero cuando corresponde.



47
48
49
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 47

def id_extranjero
  @id_extranjero
end

#monto_totalObject

Returns the value of attribute monto_total.



30
31
32
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 30

def monto_total
  @monto_total
end

#ncf_electronicoObject

Número de secuencia utilizada por el contribuyente en el e-CF. Número de comprobante fiscal electrónico (e-NCF) utilizado en la transacción.



28
29
30
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 28

def ncf_electronico
  @ncf_electronico
end

#rnc_compradorObject

RNC del comprador extraído del e-CF recibido (si aplica). Número de registro nacional del contribuyente comprador, cuando corresponde.



41
42
43
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 41

def rnc_comprador
  @rnc_comprador
end

#rnc_emisorObject

Número de registro nacional del contribuyente que envió el e-CF. RNC del emisor del comprobante fiscal electrónico.



25
26
27
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 25

def rnc_emisor
  @rnc_emisor
end

#total_itbisObject

Returns the value of attribute total_itbis.



32
33
34
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 32

def total_itbis
  @total_itbis
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 50

def self.attribute_map
  {
    :'codigo' => :'codigo',
    :'estado' => :'estado',
    :'rnc_emisor' => :'rncEmisor',
    :'ncf_electronico' => :'ncfElectronico',
    :'monto_total' => :'montoTotal',
    :'total_itbis' => :'totalITBIS',
    :'fecha_emision' => :'fechaEmision',
    :'fecha_firma' => :'fechaFirma',
    :'rnc_comprador' => :'rncComprador',
    :'codigo_seguridad' => :'codigoSeguridad',
    :'id_extranjero' => :'idExtranjero'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 94

def self.openapi_nullable
  Set.new([
    :'estado',
    :'rnc_emisor',
    :'ncf_electronico',
    :'monto_total',
    :'total_itbis',
    :'fecha_emision',
    :'fecha_firma',
    :'rnc_comprador',
    :'codigo_seguridad',
    :'id_extranjero'
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 77

def self.openapi_types
  {
    :'codigo' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner',
    :'estado' => :'String',
    :'rnc_emisor' => :'String',
    :'ncf_electronico' => :'String',
    :'monto_total' => :'RespuestaConsultaEstadoMontoTotal',
    :'total_itbis' => :'RespuestaConsultaEstadoMontoTotal',
    :'fecha_emision' => :'String',
    :'fecha_firma' => :'String',
    :'rnc_comprador' => :'String',
    :'codigo_seguridad' => :'String',
    :'id_extranjero' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      codigo == o.codigo &&
      estado == o.estado &&
      rnc_emisor == o.rnc_emisor &&
      ncf_electronico == o.ncf_electronico &&
      monto_total == o.monto_total &&
      total_itbis == o.total_itbis &&
      fecha_emision == o.fecha_emision &&
      fecha_firma == o.fecha_firma &&
      rnc_comprador == o.rnc_comprador &&
      codigo_seguridad == o.codigo_seguridad &&
      id_extranjero == o.id_extranjero
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 211

def hash
  [codigo, estado, rnc_emisor, ncf_electronico, monto_total, total_itbis, fecha_emision, fecha_firma, rnc_comprador, codigo_seguridad, id_extranjero].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 172

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_estado.rb', line 180

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end