Class: EcfDgii::Generated::RespuestaConsultaTimbre

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb

Overview

Representa la respuesta del servicio de Consulta Timbre Fiscal (QR) de la DGII. Este servicio permite validar la validez de un e-CF remitido exclusivamente por el servicio web de recepción de e-CF, a partir de los datos incluidos en el timbre de su representación impresa (RI).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RespuestaConsultaTimbre

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::RespuestaConsultaTimbre` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::RespuestaConsultaTimbre`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rnc_emisor')
    self.rnc_emisor = attributes[:'rnc_emisor']
  end

  if attributes.key?(:'razon_social')
    self.razon_social = attributes[:'razon_social']
  end

  if attributes.key?(:'encf')
    self.encf = attributes[:'encf']
  end

  if attributes.key?(:'estado')
    self.estado = attributes[:'estado']
  end
end

Instance Attribute Details

#encfObject

Número de secuencia utilizada por el contribuyente, extraído del resumen de factura de consumo. Número de comprobante fiscal electrónico (e-NCF) utilizado en la transacción.



26
27
28
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 26

def encf
  @encf
end

#estadoObject

Estado de validación otorgado por Impuestos Internos al resumen de factura de consumo recibido. Descripción textual del estado de validación del comprobante. Posibles valores: - "No fue encontrada la factura (e-CF)": El e-CF no se encontró en la base de datos de la DGII. - "Aceptado": Implica la validez del e-CF de la RI, incluyendo el aceptado condicional que corresponde a que no cumplió en algún punto pero que no amerita el rechazo de este. - "Rechazado": Corresponde a que el e-CF de la RI le fue rechazado al emisor.



29
30
31
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 29

def estado
  @estado
end

#razon_socialObject

Razón social del contribuyente que emitió el resumen de factura de consumo. Nombre comercial o razón social del emisor del comprobante fiscal electrónico.



23
24
25
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 23

def razon_social
  @razon_social
end

#rnc_emisorObject

Número de registro nacional del contribuyente que emitió el resumen de factura de consumo. RNC del emisor del comprobante fiscal electrónico consultado.



20
21
22
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 20

def rnc_emisor
  @rnc_emisor
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 32

def self.attribute_map
  {
    :'rnc_emisor' => :'rncEmisor',
    :'razon_social' => :'razonSocial',
    :'encf' => :'encf',
    :'estado' => :'estado'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 145

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
66
67
68
69
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 62

def self.openapi_nullable
  Set.new([
    :'rnc_emisor',
    :'razon_social',
    :'encf',
    :'estado'
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 52

def self.openapi_types
  {
    :'rnc_emisor' => :'String',
    :'razon_social' => :'String',
    :'encf' => :'String',
    :'estado' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



121
122
123
124
125
126
127
128
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 121

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rnc_emisor == o.rnc_emisor &&
      razon_social == o.razon_social &&
      encf == o.encf &&
      estado == o.estado
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 132

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



138
139
140
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 138

def hash
  [rnc_emisor, razon_social, encf, estado].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



106
107
108
109
110
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 106

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 167

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



114
115
116
117
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_timbre.rb', line 114

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end