Class: EcfDgii::Generated::CertificateResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::CertificateResponse
- Defined in:
- lib/ecf_dgii/generated/models/certificate_response.rb
Instance Attribute Summary collapse
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#issuer ⇒ Object
Returns the value of attribute issuer.
-
#not_after_utc ⇒ Object
Returns the value of attribute not_after_utc.
-
#not_before_utc ⇒ Object
Returns the value of attribute not_before_utc.
-
#rnc ⇒ Object
Returns the value of attribute rnc.
-
#serial_number ⇒ Object
Returns the value of attribute serial_number.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#thumbprint ⇒ Object
Returns the value of attribute thumbprint.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CertificateResponse
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::CertificateResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::CertificateResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'thumbprint') self.thumbprint = attributes[:'thumbprint'] else self.thumbprint = nil end if attributes.key?(:'subject') self.subject = attributes[:'subject'] else self.subject = nil end if attributes.key?(:'issuer') self.issuer = attributes[:'issuer'] else self.issuer = nil end if attributes.key?(:'not_before_utc') self.not_before_utc = attributes[:'not_before_utc'] else self.not_before_utc = nil end if attributes.key?(:'not_after_utc') self.not_after_utc = attributes[:'not_after_utc'] else self.not_after_utc = nil end if attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] else self.serial_number = nil end if attributes.key?(:'rnc') self.rnc = attributes[:'rnc'] else self.rnc = nil end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] else self.created_on = nil end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end end |
Instance Attribute Details
#created_by ⇒ Object
Returns the value of attribute created_by.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 34 def created_by @created_by end |
#created_on ⇒ Object
Returns the value of attribute created_on.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 32 def created_on @created_on end |
#issuer ⇒ Object
Returns the value of attribute issuer.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 22 def issuer @issuer end |
#not_after_utc ⇒ Object
Returns the value of attribute not_after_utc.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 26 def not_after_utc @not_after_utc end |
#not_before_utc ⇒ Object
Returns the value of attribute not_before_utc.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 24 def not_before_utc @not_before_utc end |
#rnc ⇒ Object
Returns the value of attribute rnc.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 30 def rnc @rnc end |
#serial_number ⇒ Object
Returns the value of attribute serial_number.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 28 def serial_number @serial_number end |
#subject ⇒ Object
Returns the value of attribute subject.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 20 def subject @subject end |
#thumbprint ⇒ Object
Returns the value of attribute thumbprint.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 18 def thumbprint @thumbprint end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 37 def self.attribute_map { :'thumbprint' => :'thumbprint', :'subject' => :'subject', :'issuer' => :'issuer', :'not_before_utc' => :'notBeforeUtc', :'not_after_utc' => :'notAfterUtc', :'serial_number' => :'serialNumber', :'rnc' => :'rnc', :'created_on' => :'createdOn', :'created_by' => :'createdBy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 320 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 81 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 77 def self.openapi_nullable Set.new([ :'rnc', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 62 def self.openapi_types { :'thumbprint' => :'String', :'subject' => :'String', :'issuer' => :'String', :'not_before_utc' => :'Time', :'not_after_utc' => :'Time', :'serial_number' => :'String', :'rnc' => :'String', :'created_on' => :'Time', :'created_by' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && thumbprint == o.thumbprint && subject == o.subject && issuer == o.issuer && not_before_utc == o.not_before_utc && not_after_utc == o.not_after_utc && serial_number == o.serial_number && rnc == o.rnc && created_on == o.created_on && created_by == o.created_by end |
#eql?(o) ⇒ Boolean
307 308 309 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 307 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 313 def hash [thumbprint, subject, issuer, not_before_utc, not_after_utc, serial_number, rnc, created_on, created_by].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @thumbprint.nil? invalid_properties.push('invalid value for "thumbprint", thumbprint cannot be nil.') end if @subject.nil? invalid_properties.push('invalid value for "subject", subject cannot be nil.') end if @issuer.nil? invalid_properties.push('invalid value for "issuer", issuer cannot be nil.') end if @not_before_utc.nil? invalid_properties.push('invalid value for "not_before_utc", not_before_utc cannot be nil.') end if @not_after_utc.nil? invalid_properties.push('invalid value for "not_after_utc", not_after_utc cannot be nil.') end if @serial_number.nil? invalid_properties.push('invalid value for "serial_number", serial_number cannot be nil.') end if @created_on.nil? invalid_properties.push('invalid value for "created_on", created_on cannot be nil.') end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/ecf_dgii/generated/models/certificate_response.rb', line 196 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @thumbprint.nil? return false if @subject.nil? return false if @issuer.nil? return false if @not_before_utc.nil? return false if @not_after_utc.nil? return false if @serial_number.nil? return false if @created_on.nil? return false if @created_by.nil? true end |