Class: EcfDgii::Generated::Directorio
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Directorio
- Defined in:
- lib/ecf_dgii/generated/models/directorio.rb
Overview
Representa una entrada del directorio para contribuyentes electrónicos en el sistema de facturación electrónica de la República Dominicana. Este modelo contiene las URLs de servicios que los contribuyentes electrónicos deben proporcionar para la comunicación entre contribuyentes.
Instance Attribute Summary collapse
-
#nombre ⇒ Object
Obtiene el nombre legal o razón social del contribuyente electrónico.
-
#rnc ⇒ Object
Obtiene el Número de Registro Nacional del Contribuyente (RNC) del contribuyente electrónico.
-
#url_aceptacion ⇒ Object
Obtiene la URL del servicio de aprobación comercial.
-
#url_opcional ⇒ Object
Obtiene la URL del servicio opcional de autenticación.
-
#url_recepcion ⇒ Object
Obtiene la URL del servicio de recepción de facturas electrónicas.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Directorio
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Directorio
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Directorio` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Directorio`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'nombre') self.nombre = attributes[:'nombre'] end if attributes.key?(:'rnc') self.rnc = attributes[:'rnc'] end if attributes.key?(:'url_recepcion') self.url_recepcion = attributes[:'url_recepcion'] end if attributes.key?(:'url_aceptacion') self.url_aceptacion = attributes[:'url_aceptacion'] end if attributes.key?(:'url_opcional') self.url_opcional = attributes[:'url_opcional'] end end |
Instance Attribute Details
#nombre ⇒ Object
Obtiene el nombre legal o razón social del contribuyente electrónico. La razón social registrada tal como aparece en el registro oficial del contribuyente. Este campo es requerido y debe coincidir con el nombre de la entidad legal del contribuyente.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 20 def nombre @nombre end |
#rnc ⇒ Object
Obtiene el Número de Registro Nacional del Contribuyente (RNC) del contribuyente electrónico. Un número de 9 dígitos que identifica de forma única al contribuyente en el sistema tributario de la República Dominicana. Este campo es requerido y debe tener un formato de RNC válido.
23 24 25 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 23 def rnc @rnc end |
#url_aceptacion ⇒ Object
Obtiene la URL del servicio de aprobación comercial. La URL completa donde otros contribuyentes pueden enviar aprobaciones comerciales para facturas recibidas. Debe seguir el formato estándar: host/ambiente/nombreservicio/fe/aprobacioncomercial/api/ecf Este campo es obligatorio para todos los contribuyentes electrónicos.
29 30 31 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 29 def url_aceptacion @url_aceptacion end |
#url_opcional ⇒ Object
Obtiene la URL del servicio opcional de autenticación. La URL base del servicio de autenticación, si es implementado por el contribuyente. Debe seguir el formato estándar: host/ambiente/nombreservicio/fe/autenticacion/api/ Este campo es opcional pero recomendado para mayor seguridad.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 32 def url_opcional @url_opcional end |
#url_recepcion ⇒ Object
Obtiene la URL del servicio de recepción de facturas electrónicas. La URL completa donde otros contribuyentes pueden enviar facturas electrónicas (e-CF) a este contribuyente. Debe seguir el formato estándar: host/ambiente/nombreservicio/fe/recepcion/api/ecf Este campo es obligatorio para todos los contribuyentes electrónicos.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 26 def url_recepcion @url_recepcion end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 35 def self.attribute_map { :'nombre' => :'nombre', :'rnc' => :'rnc', :'url_recepcion' => :'urlRecepcion', :'url_aceptacion' => :'urlAceptacion', :'url_opcional' => :'urlOpcional' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 72 73 74 75 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 67 def self.openapi_nullable Set.new([ :'nombre', :'rnc', :'url_recepcion', :'url_aceptacion', :'url_opcional' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 56 def self.openapi_types { :'nombre' => :'String', :'rnc' => :'String', :'url_recepcion' => :'String', :'url_aceptacion' => :'String', :'url_opcional' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 137 138 139 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && nombre == o.nombre && rnc == o.rnc && url_recepcion == o.url_recepcion && url_aceptacion == o.url_aceptacion && url_opcional == o.url_opcional end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 149 def hash [nombre, rnc, url_recepcion, url_aceptacion, url_opcional].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 |
# File 'lib/ecf_dgii/generated/models/directorio.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |