Class: EcfDgii::Generated::Ecf47Item
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::Ecf47Item
- Defined in:
- lib/ecf_dgii/generated/models/ecf47_item.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cantidad_item ⇒ Object
Returns the value of attribute cantidad_item.
-
#descripcion_item ⇒ Object
Returns the value of attribute descripcion_item.
-
#indicador_bieno_servicio ⇒ Object
Returns the value of attribute indicador_bieno_servicio.
-
#indicador_facturacion ⇒ Object
Returns the value of attribute indicador_facturacion.
-
#monto_item ⇒ Object
Returns the value of attribute monto_item.
-
#nombre_item ⇒ Object
Returns the value of attribute nombre_item.
-
#numero_linea ⇒ Object
Returns the value of attribute numero_linea.
-
#otra_moneda_detalle ⇒ Object
Returns the value of attribute otra_moneda_detalle.
-
#precio_unitario_item ⇒ Object
Returns the value of attribute precio_unitario_item.
-
#retencion ⇒ Object
Returns the value of attribute retencion.
-
#tabla_codigos_item ⇒ Object
Returns the value of attribute tabla_codigos_item.
-
#unidad_medida ⇒ Object
Returns the value of attribute unidad_medida.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Ecf47Item
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Ecf47Item
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::Ecf47Item` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::Ecf47Item`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'numero_linea') self.numero_linea = attributes[:'numero_linea'] else self.numero_linea = nil end if attributes.key?(:'tabla_codigos_item') if (value = attributes[:'tabla_codigos_item']).is_a?(Array) self.tabla_codigos_item = value end end if attributes.key?(:'indicador_facturacion') self.indicador_facturacion = attributes[:'indicador_facturacion'] else self.indicador_facturacion = nil end if attributes.key?(:'retencion') self.retencion = attributes[:'retencion'] else self.retencion = nil end if attributes.key?(:'nombre_item') self.nombre_item = attributes[:'nombre_item'] else self.nombre_item = nil end if attributes.key?(:'indicador_bieno_servicio') self.indicador_bieno_servicio = attributes[:'indicador_bieno_servicio'] else self.indicador_bieno_servicio = nil end if attributes.key?(:'descripcion_item') self.descripcion_item = attributes[:'descripcion_item'] end if attributes.key?(:'cantidad_item') self.cantidad_item = attributes[:'cantidad_item'] else self.cantidad_item = nil end if attributes.key?(:'unidad_medida') self.unidad_medida = attributes[:'unidad_medida'] end if attributes.key?(:'precio_unitario_item') self.precio_unitario_item = attributes[:'precio_unitario_item'] else self.precio_unitario_item = nil end if attributes.key?(:'otra_moneda_detalle') self.otra_moneda_detalle = attributes[:'otra_moneda_detalle'] end if attributes.key?(:'monto_item') self.monto_item = attributes[:'monto_item'] else self.monto_item = nil end end |
Instance Attribute Details
#cantidad_item ⇒ Object
Returns the value of attribute cantidad_item.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 32 def cantidad_item @cantidad_item end |
#descripcion_item ⇒ Object
Returns the value of attribute descripcion_item.
30 31 32 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 30 def descripcion_item @descripcion_item end |
#indicador_bieno_servicio ⇒ Object
Returns the value of attribute indicador_bieno_servicio.
28 29 30 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 28 def indicador_bieno_servicio @indicador_bieno_servicio end |
#indicador_facturacion ⇒ Object
Returns the value of attribute indicador_facturacion.
22 23 24 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 22 def indicador_facturacion @indicador_facturacion end |
#monto_item ⇒ Object
Returns the value of attribute monto_item.
40 41 42 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 40 def monto_item @monto_item end |
#nombre_item ⇒ Object
Returns the value of attribute nombre_item.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 26 def nombre_item @nombre_item end |
#numero_linea ⇒ Object
Returns the value of attribute numero_linea.
18 19 20 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 18 def numero_linea @numero_linea end |
#otra_moneda_detalle ⇒ Object
Returns the value of attribute otra_moneda_detalle.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 38 def otra_moneda_detalle @otra_moneda_detalle end |
#precio_unitario_item ⇒ Object
Returns the value of attribute precio_unitario_item.
36 37 38 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 36 def precio_unitario_item @precio_unitario_item end |
#retencion ⇒ Object
Returns the value of attribute retencion.
24 25 26 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 24 def retencion @retencion end |
#tabla_codigos_item ⇒ Object
Returns the value of attribute tabla_codigos_item.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 20 def tabla_codigos_item @tabla_codigos_item end |
#unidad_medida ⇒ Object
Returns the value of attribute unidad_medida.
34 35 36 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 34 def unidad_medida @unidad_medida end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 65 def self.attribute_map { :'numero_linea' => :'numeroLinea', :'tabla_codigos_item' => :'tablaCodigosItem', :'indicador_facturacion' => :'indicadorFacturacion', :'retencion' => :'retencion', :'nombre_item' => :'nombreItem', :'indicador_bieno_servicio' => :'indicadorBienoServicio', :'descripcion_item' => :'descripcionItem', :'cantidad_item' => :'cantidadItem', :'unidad_medida' => :'unidadMedida', :'precio_unitario_item' => :'precioUnitarioItem', :'otra_moneda_detalle' => :'otraMonedaDetalle', :'monto_item' => :'montoItem' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 372 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 115 116 117 118 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 111 def self.openapi_nullable Set.new([ :'tabla_codigos_item', :'descripcion_item', :'unidad_medida', :'otra_moneda_detalle', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 93 def self.openapi_types { :'numero_linea' => :'SearchEcfReceptionRequestsTiposEcfsParameterInner', :'tabla_codigos_item' => :'Array<Ecf47CodigosItem>', :'indicador_facturacion' => :'Ecf47IndicadorFacturacionType', :'retencion' => :'Ecf47Retencion', :'nombre_item' => :'String', :'indicador_bieno_servicio' => :'Ecf47IndicadorBienoServicioType', :'descripcion_item' => :'String', :'cantidad_item' => :'Ecf31ItemCantidadItem', :'unidad_medida' => :'UnidadMedidaType', :'precio_unitario_item' => :'Ecf31ItemPrecioUnitarioItem', :'otra_moneda_detalle' => :'Ecf47OtraMonedaDetalle', :'monto_item' => :'Ecf31FormaDePagoMontoPago' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 340 def ==(o) return true if self.equal?(o) self.class == o.class && numero_linea == o.numero_linea && tabla_codigos_item == o.tabla_codigos_item && indicador_facturacion == o.indicador_facturacion && retencion == o.retencion && nombre_item == o.nombre_item && indicador_bieno_servicio == o.indicador_bieno_servicio && descripcion_item == o.descripcion_item && cantidad_item == o.cantidad_item && unidad_medida == o.unidad_medida && precio_unitario_item == o.precio_unitario_item && otra_moneda_detalle == o.otra_moneda_detalle && monto_item == o.monto_item end |
#eql?(o) ⇒ Boolean
359 360 361 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 359 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
365 366 367 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 365 def hash [numero_linea, tabla_codigos_item, indicador_facturacion, retencion, nombre_item, indicador_bieno_servicio, descripcion_item, cantidad_item, unidad_medida, precio_unitario_item, otra_moneda_detalle, monto_item].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @numero_linea.nil? invalid_properties.push('invalid value for "numero_linea", numero_linea cannot be nil.') end if @indicador_facturacion.nil? invalid_properties.push('invalid value for "indicador_facturacion", indicador_facturacion cannot be nil.') end if @retencion.nil? invalid_properties.push('invalid value for "retencion", retencion cannot be nil.') end if @nombre_item.nil? invalid_properties.push('invalid value for "nombre_item", nombre_item cannot be nil.') end if @indicador_bieno_servicio.nil? invalid_properties.push('invalid value for "indicador_bieno_servicio", indicador_bieno_servicio cannot be nil.') end if @cantidad_item.nil? invalid_properties.push('invalid value for "cantidad_item", cantidad_item cannot be nil.') end if @precio_unitario_item.nil? invalid_properties.push('invalid value for "precio_unitario_item", precio_unitario_item cannot be nil.') end if @monto_item.nil? invalid_properties.push('invalid value for "monto_item", monto_item cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 394 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/ecf_dgii/generated/models/ecf47_item.rb', line 245 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @numero_linea.nil? return false if @indicador_facturacion.nil? return false if @retencion.nil? return false if @nombre_item.nil? return false if @indicador_bieno_servicio.nil? return false if @cantidad_item.nil? return false if @precio_unitario_item.nil? return false if @monto_item.nil? true end |