Class: EcfDgii::Generated::RespuestaConsultaRFCE
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::RespuestaConsultaRFCE
- Defined in:
- lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb
Overview
Representa la respuesta del servicio de Consulta de Resumen de Factura (RFCE) de la DGII. Este servicio permite validar la validez fiscal de un comprobante fiscal electrónico a través del RNC emisor, e-NCF y código de seguridad.
Instance Attribute Summary collapse
-
#codigo ⇒ Object
Código asociado al estado de validación del e-CF recibido.
-
#encf ⇒ Object
Número de secuencia utilizada por el contribuyente en el ENCF.
-
#estado ⇒ Object
Estado de validación otorgado por Impuestos Internos al e-CF recibido.
-
#mensajes ⇒ Object
Mensajes y códigos asociados al estado de validación del e-CF recibido.
-
#rnc ⇒ Object
Número de registro nacional del contribuyente que envió el e-CF.
-
#secuencia_utilizada ⇒ Object
Indica si el número de secuencia puede ser reutilizado.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RespuestaConsultaRFCE
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RespuestaConsultaRFCE
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::RespuestaConsultaRFCE` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::RespuestaConsultaRFCE`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'rnc') self.rnc = attributes[:'rnc'] end if attributes.key?(:'encf') self.encf = attributes[:'encf'] end if attributes.key?(:'secuencia_utilizada') self.secuencia_utilizada = attributes[:'secuencia_utilizada'] end if attributes.key?(:'codigo') self.codigo = attributes[:'codigo'] end if attributes.key?(:'estado') self.estado = attributes[:'estado'] end if attributes.key?(:'mensajes') if (value = attributes[:'mensajes']).is_a?(Array) self.mensajes = value end end end |
Instance Attribute Details
#codigo ⇒ Object
Código asociado al estado de validación del e-CF recibido. Código numérico que indica el resultado de la validación: - 0: No encontrado - 1: Aceptado - 2: Rechazado - 4: Aceptado Condicional (solo para FC < RD$ 250000.00)
29 30 31 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 29 def codigo @codigo end |
#encf ⇒ Object
Número de secuencia utilizada por el contribuyente en el ENCF. Número de comprobante fiscal electrónico (e-NCF) consultado.
23 24 25 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 23 def encf @encf end |
#estado ⇒ Object
Estado de validación otorgado por Impuestos Internos al e-CF recibido. Descripción textual del estado de validación del comprobante.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 32 def estado @estado end |
#mensajes ⇒ Object
Mensajes y códigos asociados al estado de validación del e-CF recibido. Array de mensajes que proporcionan detalles adicionales sobre la validación.
35 36 37 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 35 def mensajes @mensajes end |
#rnc ⇒ Object
Número de registro nacional del contribuyente que envió el e-CF. RNC del emisor del comprobante fiscal electrónico consultado.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 20 def rnc @rnc end |
#secuencia_utilizada ⇒ Object
Indica si el número de secuencia puede ser reutilizado. ‘true` si la secuencia NO puede reutilizarse (rechazado por motivos específicos); `false` si la secuencia SÍ puede reutilizarse.
26 27 28 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 26 def secuencia_utilizada @secuencia_utilizada end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 38 def self.attribute_map { :'rnc' => :'rnc', :'encf' => :'encf', :'secuencia_utilizada' => :'secuenciaUtilizada', :'codigo' => :'codigo', :'estado' => :'estado', :'mensajes' => :'mensajes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 76 77 78 79 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 72 def self.openapi_nullable Set.new([ :'rnc', :'codigo', :'estado', :'mensajes' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 60 def self.openapi_types { :'rnc' => :'String', :'encf' => :'String', :'secuencia_utilizada' => :'Boolean', :'codigo' => :'String', :'estado' => :'String', :'mensajes' => :'Array<Mensaje>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 141 def ==(o) return true if self.equal?(o) self.class == o.class && rnc == o.rnc && encf == o.encf && secuencia_utilizada == o.secuencia_utilizada && codigo == o.codigo && estado == o.estado && mensajes == o.mensajes end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 160 def hash [rnc, encf, secuencia_utilizada, codigo, estado, mensajes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_rfce.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |