Class: EcfDgii::Generated::RespuestaConsultaTrackId
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- EcfDgii::Generated::RespuestaConsultaTrackId
- Defined in:
- lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb
Overview
Representa la respuesta del servicio de consulta de resultado de comprobantes fiscales electrónicos (e-CF). Este modelo contiene la información completa sobre el estado de procesamiento y validación de un e-CF que fue enviado previamente mediante el servicio de recepción.
Instance Attribute Summary collapse
-
#codigo ⇒ Object
Obtiene el código asociado al estado de validación del e-CF recibido.
-
#encf ⇒ Object
Obtiene el número de secuencia utilizada por el contribuyente en el e-CF.
-
#estado ⇒ Object
Obtiene el estado de validación otorgado por Impuestos Internos al e-CF recibido.
-
#fecha_recepcion ⇒ Object
Obtiene la fecha en la cual Impuestos Internos recibió el e-CF.
-
#mensajes ⇒ Object
Obtiene los mensajes asociados al estado de validación del e-CF recibido.
-
#rnc ⇒ Object
Obtiene el número de registro nacional del contribuyente que envió el e-CF.
-
#secuencia_utilizada ⇒ Object
Indica si el número de secuencia puede ser reutilizada en otro e-CF.
-
#track_id ⇒ Object
Obtiene el número único generado por Impuestos Internos para identificar un e-CF recibido.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RespuestaConsultaTrackId
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RespuestaConsultaTrackId
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EcfDgii::Generated::RespuestaConsultaTrackId` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EcfDgii::Generated::RespuestaConsultaTrackId`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'track_id') self.track_id = attributes[:'track_id'] end if attributes.key?(:'codigo') self.codigo = attributes[:'codigo'] end if attributes.key?(:'estado') self.estado = attributes[:'estado'] end if attributes.key?(:'rnc') self.rnc = attributes[:'rnc'] end if attributes.key?(:'encf') self.encf = attributes[:'encf'] end if attributes.key?(:'secuencia_utilizada') self.secuencia_utilizada = attributes[:'secuencia_utilizada'] end if attributes.key?(:'fecha_recepcion') self.fecha_recepcion = attributes[:'fecha_recepcion'] end if attributes.key?(:'mensajes') if (value = attributes[:'mensajes']).is_a?(Array) self.mensajes = value end end end |
Instance Attribute Details
#codigo ⇒ Object
Obtiene el código asociado al estado de validación del e-CF recibido. Un código que indica el resultado de la validación. Los valores típicos son: - "0": No encontrado - "1": Aceptado - "2": Rechazado - "3": En Proceso - "4": Aceptado Condicional
23 24 25 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 23 def codigo @codigo end |
#encf ⇒ Object
Obtiene el número de secuencia utilizada por el contribuyente en el e-CF. El número de comprobante fiscal electrónico (e-NCF). Puede ser null si no está disponible.
32 33 34 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 32 def encf @encf end |
#estado ⇒ Object
Obtiene el estado de validación otorgado por Impuestos Internos al e-CF recibido. Descripción textual del estado. Puede incluir valores como: - "No encontrado": No se encontró el trackid en los registros - "Aceptado": Implica la validez del e-CF - "Rechazado": Implica la nulidad del comprobante para fines tributarios - "En Proceso": El comprobante aún no ha sido validado - "Aceptado Condicional": El comprobante no cumplió en algún punto pero no ameritó el rechazo
26 27 28 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 26 def estado @estado end |
#fecha_recepcion ⇒ Object
Obtiene la fecha en la cual Impuestos Internos recibió el e-CF. La fecha de recepción del comprobante. Puede ser null si no está disponible. El formato típico es ISO 8601 o un formato de fecha legible.
38 39 40 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 38 def fecha_recepcion @fecha_recepcion end |
#mensajes ⇒ Object
Obtiene los mensajes asociados al estado de validación del e-CF recibido. Un array de mensajes que proporcionan información detallada sobre el estado de validación. Puede ser null si no hay mensajes disponibles.
41 42 43 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 41 def mensajes @mensajes end |
#rnc ⇒ Object
Obtiene el número de registro nacional del contribuyente que envió el e-CF. El RNC del emisor del comprobante. Puede ser null si no está disponible.
29 30 31 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 29 def rnc @rnc end |
#secuencia_utilizada ⇒ Object
Indica si el número de secuencia puede ser reutilizada en otro e-CF. True si la secuencia puede reutilizarse, False si no puede reutilizarse. Este parámetro permite dar a conocer si el número de secuencia que fue recibido por Impuestos Internos puede reutilizarse en otro Comprobante Fiscal Electrónico (e-CF) en el escenario de que el resultado de la validación haya sido "Rechazado" por los siguientes motivos: - Certificado y/o firma inválida - Estructura del comprobante (XML) no es válida - Firmante del comprobante fiscal electrónico no corresponde a un delegado autorizado - El e-NCF no está autorizado para el RNC Emisor - El e-NCF autorizado se encuentra vencido - El RNC Emisor no corresponde a un emisor electrónico - El RNC Emisor no existe o no se encuentra activo
35 36 37 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 35 def secuencia_utilizada @secuencia_utilizada end |
#track_id ⇒ Object
Obtiene el número único generado por Impuestos Internos para identificar un e-CF recibido. Este identificador se obtiene como respuesta del servicio de recepción de e-CF. El identificador único del track. Puede ser null si no está disponible.
20 21 22 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 20 def track_id @track_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 44 def self.attribute_map { :'track_id' => :'trackId', :'codigo' => :'codigo', :'estado' => :'estado', :'rnc' => :'rnc', :'encf' => :'encf', :'secuencia_utilizada' => :'secuenciaUtilizada', :'fecha_recepcion' => :'fechaRecepcion', :'mensajes' => :'mensajes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 82 def self.openapi_nullable Set.new([ :'track_id', :'codigo', :'estado', :'rnc', :'encf', :'fecha_recepcion', :'mensajes' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 68 def self.openapi_types { :'track_id' => :'String', :'codigo' => :'String', :'estado' => :'String', :'rnc' => :'String', :'encf' => :'String', :'secuencia_utilizada' => :'Boolean', :'fecha_recepcion' => :'String', :'mensajes' => :'Array<Mensaje>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && track_id == o.track_id && codigo == o.codigo && estado == o.estado && rnc == o.rnc && encf == o.encf && secuencia_utilizada == o.secuencia_utilizada && fecha_recepcion == o.fecha_recepcion && mensajes == o.mensajes end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 183 def hash [track_id, codigo, estado, rnc, encf, secuencia_utilizada, fecha_recepcion, mensajes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 |
# File 'lib/ecf_dgii/generated/models/respuesta_consulta_track_id.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |